;; ./mach.d/c99tab.scm

;; Copyright (C) 2016-2018 Matthew R. Wette
;; 
;; This library is free software; you can redistribute it and/or
;; modify it under the terms of the GNU Lesser General Public
;; License as published by the Free Software Foundation; either
;; version 3 of the License, or (at your option) any later version.
;; See the file COPYING.LESSER included with the this distribution.

(define c99-len-v
  #(1 1 1 1 3 5 1 4 4 3 3 3 2 2 6 7 1 3 1 3 2 1 1 2 2 2 2 4 1 1 1 1 1 1 1 4 1
    3 3 3 1 3 3 1 3 3 1 3 3 3 3 1 3 3 1 3 1 3 1 3 1 3 1 3 1 5 1 3 1 1 1 1 1 1 
    1 1 1 1 1 1 3 1 6 3 0 1 2 1 2 1 2 1 2 1 3 1 2 3 4 1 1 1 1 1 1 1 1 1 1 1 1 
    1 1 2 2 3 1 1 2 1 2 2 3 2 3 3 4 3 2 2 1 3 2 4 3 1 2 2 1 1 2 1 2 2 3 1 2 6 
    1 1 1 1 1 1 0 1 2 3 1 4 1 3 1 1 1 1 1 1 4 0 1 6 5 2 6 5 2 6 5 6 5 1 1 1 1 
    2 2 1 2 5 3 2 1 2 1 1 3 1 3 2 5 6 4 5 2 1 3 1 3 1 1 1 1 1 2 1 1 3 5 4 4 3 
    6 6 5 4 4 4 3 3 2 2 1 1 2 1 3 1 3 2 2 1 1 3 2 1 2 1 1 3 5 4 4 3 6 5 6 4 3 
    3 2 5 4 5 4 3 4 3 3 2 1 1 3 4 2 1 4 3 2 1 2 3 2 1 1 1 1 1 1 1 1 3 4 3 3 2 
    1 2 1 1 2 1 5 7 5 5 7 8 2 1 1 0 1 3 2 2 3 2 2 4 5 6 7 1 2 3 4 7 1 2 3 4 7 
    1 2 3 1 0 2 1 1 2 1 1 1 7 1 0 0 4 3 1 2 0 1 1 1 1 1 1 1 1 1 1 2 1 1 1 4))

(define c99-pat-v
  #(((116 . 1) (212 . 2) (5 . -337) (1 . -337)) ((27 . 3) (34 . 4) (35 . 5) 
    (36 . 6) (44 . 7) (45 . 8) (46 . 9) (47 . 10) (48 . 11) (49 . 12) (51 . 13
    ) (50 . 14) (53 . 15) (29 . 16) (30 . 17) (31 . 18) (32 . 19) (33 . 20) 
    (40 . 21) (41 . 22) (42 . 23) (165 . 24) (166 . 25) (167 . 26) (168 . 27) 
    (54 . 28) (169 . 29) (170 . 30) (55 . 31) (56 . 32) (57 . 33) (58 . 34) 
    (60 . 35) (161 . 36) (43 . 37) (175 . 38) (176 . 39) (177 . 40) (178 . 41)
    (3 . 42) (4 . 43) (5 . 44) (164 . 45) (199 . 46) (61 . 47) (59 . 48) 
    (113 . 49) (127 . 50) (152 . 51) (163 . 52) (124 . 53) (114 . 54) (115 . 
    55) (108 . -336)) ((108 . 0)) ((1 . -270)) ((104 . 100) (12 . 64) (39 . 65
    ) (27 . 3) (165 . 93) (211 . 94) (155 . 101)) ((104 . 97) (12 . 64) 
    (39 . 65) (27 . 3) (165 . 93) (211 . 94) (155 . 98) (40 . 21) (41 . 22) 
    (42 . 23) (161 . 36) (43 . 37) (164 . 45) (163 . 99)) ((104 . 92) (12 . 64
    ) (39 . 65) (27 . 3) (165 . 93) (211 . 94) (155 . 95) (40 . 21) (41 . 22) 
    (42 . 23) (161 . 36) (43 . 37) (164 . 45) (163 . 96)) ((1 . -141)) 
    ((44 . 91) (1 . -139)) ((44 . 90) (1 . -138)) ((1 . -135)) ((53 . 86) 
    (51 . 87) (49 . 88) (47 . 89) (1 . -130)) ((51 . 83) (49 . 84) (45 . 85) 
    (1 . -119)) ((1 . -116)) ((53 . 79) (51 . 80) (49 . 81) (47 . 82) (1 . 
    -117)) ((51 . 78) (1 . -112)) ((1 . -213)) ((1 . -212)) ((1 . -211)) 
    ((1 . -210)) ((1 . -209)) ((1 . -151)) ((1 . -150)) ((1 . -149)) ((1 . 
    -111)) ((1 . -110)) ((1 . -109)) ((1 . -108)) ((1 . -107)) ((1 . -106)) 
    ((1 . -105)) ((1 . -104)) ((1 . -103)) ((1 . -102)) ((1 . -101)) ((1 . -99
    )) ((1 . -148)) ((106 . 77)) ((27 . 3) (34 . 4) (35 . 5) (36 . 6) (44 . 7)
    (45 . 8) (46 . 9) (47 . 10) (48 . 11) (49 . 12) (51 . 13) (50 . 14) 
    (53 . 15) (29 . 16) (30 . 17) (31 . 18) (32 . 19) (33 . 20) (165 . 24) 
    (166 . 25) (167 . 26) (168 . 27) (54 . 28) (169 . 29) (170 . 30) (55 . 31)
    (56 . 32) (57 . 33) (58 . 34) (59 . 56) (60 . 35) (175 . 38) (176 . 39) 
    (177 . 40) (178 . 41) (199 . 76) (1 . -91)) ((27 . 3) (34 . 4) (35 . 5) 
    (36 . 6) (44 . 7) (45 . 8) (46 . 9) (47 . 10) (48 . 11) (49 . 12) (51 . 13
    ) (50 . 14) (53 . 15) (29 . 16) (30 . 17) (31 . 18) (32 . 19) (33 . 20) 
    (165 . 24) (166 . 25) (167 . 26) (168 . 27) (54 . 28) (169 . 29) (170 . 30
    ) (55 . 31) (56 . 32) (57 . 33) (58 . 34) (59 . 56) (60 . 35) (175 . 38) 
    (176 . 39) (177 . 40) (178 . 41) (199 . 75) (1 . -89)) ((27 . 3) (34 . 4) 
    (35 . 5) (36 . 6) (44 . 7) (45 . 8) (46 . 9) (47 . 10) (48 . 11) (49 . 12)
    (51 . 13) (50 . 14) (53 . 15) (29 . 16) (30 . 17) (31 . 18) (32 . 19) 
    (33 . 20) (165 . 24) (166 . 25) (167 . 26) (168 . 27) (54 . 28) (169 . 29)
    (170 . 30) (55 . 31) (56 . 32) (57 . 33) (58 . 34) (59 . 56) (60 . 35) 
    (175 . 38) (176 . 39) (177 . 40) (178 . 41) (199 . 74) (1 . -87)) (
    (27 . 3) (34 . 4) (35 . 5) (36 . 6) (44 . 7) (45 . 8) (46 . 9) (47 . 10) 
    (48 . 11) (49 . 12) (51 . 13) (50 . 14) (53 . 15) (29 . 16) (30 . 17) 
    (31 . 18) (32 . 19) (33 . 20) (165 . 24) (166 . 25) (167 . 26) (168 . 27) 
    (54 . 28) (169 . 29) (170 . 30) (55 . 31) (56 . 32) (57 . 33) (58 . 34) 
    (59 . 56) (60 . 35) (175 . 38) (176 . 39) (177 . 40) (178 . 41) (199 . 73)
    (1 . -85)) ((106 . 72)) ((5 . -367) (1 . -367)) ((5 . -366) (1 . -366)) 
    ((1 . -145)) ((174 . 61) (182 . 62) (61 . 63) (12 . 64) (39 . 65) (93 . 66
    ) (106 . 67) (211 . 68) (144 . 69) (145 . 70) (173 . 71)) ((5 . -346) 
    (1 . -346)) ((37 . 60) (1 . -100)) ((5 . -344) (1 . -344)) ((5 . -343) 
    (1 . -343)) ((5 . -342) (1 . -342)) ((27 . 3) (34 . 4) (35 . 5) (36 . 6) 
    (44 . 7) (45 . 8) (46 . 9) (47 . 10) (48 . 11) (49 . 12) (51 . 13) 
    (50 . 14) (53 . 15) (29 . 16) (30 . 17) (31 . 18) (32 . 19) (33 . 20) 
    (165 . 24) (166 . 25) (167 . 26) (168 . 27) (54 . 28) (169 . 29) (170 . 30
    ) (55 . 31) (56 . 32) (57 . 33) (58 . 34) (59 . 56) (60 . 35) (175 . 38) 
    (176 . 39) (177 . 40) (178 . 41) (199 . 57) (124 . 58) (40 . 21) (41 . 22)
    (42 . 23) (161 . 36) (43 . 37) (164 . 59)) ((5 . -340) (1 . -340)) 
    ((5 . -339) (1 . -339)) ((5 . -338) (1 . -338)) ((1 . -100)) ((12 . 64) 
    (39 . 65) (93 . 66) (106 . 67) (211 . 68) (144 . 69) (145 . 70) (173 . 152
    ) (174 . 61) (182 . 62) (61 . 63)) ((5 . -341) (1 . -341)) ((1 . -146)) 
    ((104 . 151)) ((1 . -93)) ((40 . 21) (41 . 22) (42 . 23) (161 . 36) 
    (43 . 37) (164 . 45) (163 . 148) (181 . 149) (96 . 150) (61 . -169)) 
    ((6 . 145) (109 . 146) (179 . 147) (5 . -353) (1 . -353)) ((1 . -356)) 
    ((1 . -355)) ((31 . 18) (32 . 19) (33 . 20) (176 . 142) (143 . 143) 
    (93 . 66) (145 . 144) (1 . -232)) ((12 . 64) (39 . 65) (93 . 66) (106 . 67
    ) (211 . 68) (144 . 69) (145 . 70) (173 . 141)) ((1 . -216)) ((102 . 139) 
    (106 . 140) (1 . -215)) ((12 . 64) (39 . 65) (106 . 67) (211 . 68) 
    (144 . 138)) ((104 . 131) (133 . 132) (27 . 3) (34 . 4) (35 . 5) (36 . 6) 
    (44 . 7) (45 . 8) (46 . 9) (47 . 10) (48 . 11) (49 . 12) (51 . 13) 
    (50 . 14) (53 . 15) (29 . 16) (30 . 17) (31 . 18) (32 . 19) (33 . 20) 
    (165 . 24) (166 . 25) (167 . 26) (168 . 27) (54 . 28) (169 . 29) (170 . 30
    ) (55 . 31) (56 . 32) (57 . 33) (58 . 34) (59 . 56) (60 . 35) (175 . 38) 
    (176 . 39) (177 . 40) (178 . 41) (199 . 57) (124 . 133) (110 . 134) 
    (72 . 135) (13 . 136) (172 . 137) (1 . -95)) ((37 . 129) (209 . 130)) 
    ((1 . -86)) ((1 . -88)) ((1 . -90)) ((1 . -92)) ((106 . 128)) ((1 . -113))
    ((51 . 127) (1 . -114)) ((1 . -118)) ((49 . 125) (51 . 126) (1 . -121)) 
    ((1 . -136)) ((1 . -120)) ((51 . 124) (1 . -123)) ((44 . 123) (1 . -140)) 
    ((51 . 122) (1 . -128)) ((1 . -129)) ((49 . 120) (51 . 121) (1 . -132)) 
    ((1 . -137)) ((1 . -142)) ((1 . -143)) ((27 . 3) (34 . 4) (35 . 5) 
    (36 . 6) (44 . 7) (45 . 8) (46 . 9) (47 . 10) (48 . 11) (49 . 12) (51 . 13
    ) (50 . 14) (53 . 15) (31 . 18) (32 . 19) (33 . 20) (165 . 24) (166 . 25) 
    (167 . 26) (168 . 27) (54 . 28) (169 . 29) (170 . 30) (55 . 31) (176 . 109
    ) (177 . 110) (5 . 44) (151 . 111) (61 . 112) (152 . 113) (153 . 114) 
    (154 . 119)) ((1 . -182)) ((1 . -181)) ((104 . 118) (1 . -173)) ((104 . 
    116) (40 . 21) (41 . 22) (42 . 23) (161 . 36) (43 . 37) (164 . 59) 
    (12 . 64) (39 . 65) (27 . 3) (165 . 93) (211 . 94) (155 . 117)) ((27 . 3) 
    (34 . 4) (35 . 5) (36 . 6) (44 . 7) (45 . 8) (46 . 9) (47 . 10) (48 . 11) 
    (49 . 12) (51 . 13) (50 . 14) (53 . 15) (31 . 18) (32 . 19) (33 . 20) 
    (165 . 24) (166 . 25) (167 . 26) (168 . 27) (54 . 28) (169 . 29) (170 . 30
    ) (55 . 31) (176 . 109) (177 . 110) (5 . 44) (151 . 111) (61 . 112) 
    (152 . 113) (153 . 114) (154 . 115)) ((104 . 108) (1 . -176)) ((104 . 106)
    (40 . 21) (41 . 22) (42 . 23) (161 . 36) (43 . 37) (164 . 59) (12 . 64) 
    (39 . 65) (27 . 3) (165 . 93) (211 . 94) (155 . 107)) ((12 . 64) (39 . 65)
    (211 . 103) (146 . 104) (147 . 105)) ((104 . 102) (1 . -204)) ((12 . 64) 
    (39 . 65) (211 . 103) (146 . 104) (147 . 272)) ((72 . 271) (103 . -207) 
    (96 . -207)) ((103 . -205) (96 . -205)) ((103 . 269) (96 . 270)) ((27 . 3)
    (34 . 4) (35 . 5) (36 . 6) (44 . 7) (45 . 8) (46 . 9) (47 . 10) (48 . 11) 
    (49 . 12) (51 . 13) (50 . 14) (53 . 15) (31 . 18) (32 . 19) (33 . 20) 
    (165 . 24) (166 . 25) (167 . 26) (168 . 27) (54 . 28) (169 . 29) (170 . 30
    ) (55 . 31) (176 . 109) (177 . 110) (5 . 44) (151 . 111) (61 . 112) 
    (152 . 113) (153 . 114) (154 . 268)) ((104 . 267)) ((27 . 3) (34 . 4) 
    (35 . 5) (36 . 6) (44 . 7) (45 . 8) (46 . 9) (47 . 10) (48 . 11) (49 . 12)
    (51 . 13) (50 . 14) (53 . 15) (31 . 18) (32 . 19) (33 . 20) (165 . 24) 
    (166 . 25) (167 . 26) (168 . 27) (54 . 28) (169 . 29) (170 . 30) (55 . 31)
    (176 . 109) (177 . 110) (5 . 44) (151 . 111) (61 . 112) (152 . 113) 
    (153 . 114) (154 . 266)) ((27 . 3) (34 . 4) (35 . 5) (36 . 6) (44 . 7) 
    (45 . 8) (46 . 9) (47 . 10) (48 . 11) (49 . 12) (51 . 13) (50 . 14) 
    (53 . 15) (31 . 18) (32 . 19) (33 . 20) (165 . 24) (166 . 25) (167 . 26) 
    (168 . 27) (54 . 28) (169 . 29) (170 . 30) (55 . 31) (176 . 109) (177 . 
    110) (151 . 265) (1 . -194)) ((27 . 3) (34 . 4) (35 . 5) (36 . 6) (44 . 7)
    (45 . 8) (46 . 9) (47 . 10) (48 . 11) (49 . 12) (51 . 13) (50 . 14) 
    (53 . 15) (31 . 18) (32 . 19) (33 . 20) (165 . 24) (166 . 25) (167 . 26) 
    (168 . 27) (54 . 28) (169 . 29) (170 . 30) (55 . 31) (176 . 109) (177 . 
    110) (151 . 264) (1 . -192)) ((12 . 64) (39 . 65) (93 . 66) (106 . 67) 
    (211 . 68) (144 . 69) (145 . 70) (73 . 259) (173 . 260) (149 . 261) 
    (150 . 262) (61 . 263)) ((5 . -187) (1 . -187)) ((5 . -184) (1 . -184)) 
    ((5 . -183) (1 . -183)) ((103 . 258) (27 . 3) (34 . 4) (35 . 5) (36 . 6) 
    (44 . 7) (45 . 8) (46 . 9) (47 . 10) (48 . 11) (49 . 12) (51 . 13) 
    (50 . 14) (53 . 15) (31 . 18) (32 . 19) (33 . 20) (165 . 24) (166 . 25) 
    (167 . 26) (168 . 27) (54 . 28) (169 . 29) (170 . 30) (55 . 31) (176 . 109
    ) (177 . 110) (151 . 111) (153 . 252) (5 . 44) (152 . 253) (61 . 254)) 
    ((27 . 3) (34 . 4) (35 . 5) (36 . 6) (44 . 7) (45 . 8) (46 . 9) (47 . 10) 
    (48 . 11) (49 . 12) (51 . 13) (50 . 14) (53 . 15) (31 . 18) (32 . 19) 
    (33 . 20) (165 . 24) (166 . 25) (167 . 26) (168 . 27) (54 . 28) (169 . 29)
    (170 . 30) (55 . 31) (176 . 109) (177 . 110) (5 . 44) (151 . 111) (61 . 
    112) (152 . 113) (153 . 114) (154 . 257)) ((104 . 256)) ((27 . 3) (34 . 4)
    (35 . 5) (36 . 6) (44 . 7) (45 . 8) (46 . 9) (47 . 10) (48 . 11) (49 . 12)
    (51 . 13) (50 . 14) (53 . 15) (31 . 18) (32 . 19) (33 . 20) (165 . 24) 
    (166 . 25) (167 . 26) (168 . 27) (54 . 28) (169 . 29) (170 . 30) (55 . 31)
    (176 . 109) (177 . 110) (5 . 44) (151 . 111) (61 . 112) (152 . 113) 
    (153 . 114) (154 . 255)) ((103 . 251) (27 . 3) (34 . 4) (35 . 5) (36 . 6) 
    (44 . 7) (45 . 8) (46 . 9) (47 . 10) (48 . 11) (49 . 12) (51 . 13) 
    (50 . 14) (53 . 15) (31 . 18) (32 . 19) (33 . 20) (165 . 24) (166 . 25) 
    (167 . 26) (168 . 27) (54 . 28) (169 . 29) (170 . 30) (55 . 31) (176 . 109
    ) (177 . 110) (151 . 111) (153 . 252) (5 . 44) (152 . 253) (61 . 254)) 
    ((51 . 250) (1 . -134)) ((1 . -131)) ((1 . -127)) ((1 . -144)) ((1 . -124)
    ) ((51 . 249) (1 . -125)) ((1 . -122)) ((1 . -115)) ((40 . 21) (41 . 22) 
    (42 . 23) (39 . 244) (161 . 245) (159 . 246) (160 . 247) (162 . 248) 
    (105 . -154) (96 . -154)) ((1 . -363)) ((105 . 242) (37 . 243)) ((195 . 
    168) (194 . 169) (193 . 170) (192 . 171) (191 . 172) (190 . 173) (189 . 
    174) (37 . 129) (7 . 175) (8 . 176) (9 . 177) (10 . 178) (11 . 179) 
    (38 . 180) (188 . 181) (187 . 182) (209 . 183) (210 . 184) (186 . 186) 
    (89 . 187) (90 . 188) (91 . 189) (92 . 190) (93 . 207) (94 . 192) (106 . 
    193) (206 . 194) (185 . 195) (95 . 196) (196 . 197) (97 . 198) (98 . 199) 
    (205 . 200) (27 . 3) (34 . 4) (35 . 5) (36 . 6) (44 . 7) (45 . 8) (46 . 9)
    (47 . 10) (48 . 11) (49 . 12) (51 . 13) (50 . 14) (53 . 15) (197 . 201) 
    (184 . 202) (12 . 64) (39 . 65) (13 . 136) (29 . 16) (30 . 17) (31 . 18) 
    (32 . 19) (33 . 20) (165 . 24) (166 . 25) (167 . 26) (168 . 27) (54 . 28) 
    (169 . 29) (170 . 30) (55 . 31) (56 . 32) (57 . 33) (58 . 34) (59 . 56) 
    (60 . 35) (201 . 213) (4 . 43) (172 . 214) (14 . 215) (15 . 216) (16 . 217
    ) (17 . 218) (18 . 219) (19 . 220) (20 . 221) (21 . 222) (24 . 223) 
    (61 . 224) (208 . 225) (104 . 131) (25 . 226) (26 . 227) (211 . 228) 
    (175 . 38) (176 . 39) (177 . 40) (178 . 41) (127 . 229) (128 . 230) 
    (129 . 231) (130 . 232) (131 . 233) (132 . 234) (133 . 235) (134 . 236) 
    (199 . 57) (126 . 237) (124 . 238) (125 . 239) (207 . 240) (103 . 241)) 
    ((5 . -350) (1 . -350)) ((1 . -351)) ((104 . 131) (133 . 211) (27 . 3) 
    (34 . 4) (35 . 5) (36 . 6) (44 . 7) (45 . 8) (46 . 9) (47 . 10) (48 . 11) 
    (49 . 12) (51 . 13) (50 . 14) (53 . 15) (29 . 16) (30 . 17) (31 . 18) 
    (32 . 19) (33 . 20) (165 . 24) (166 . 25) (167 . 26) (168 . 27) (54 . 28) 
    (169 . 29) (170 . 30) (55 . 31) (56 . 32) (57 . 33) (58 . 34) (59 . 56) 
    (60 . 35) (175 . 38) (176 . 39) (177 . 40) (178 . 41) (199 . 57) (124 . 
    212)) ((195 . 168) (194 . 169) (193 . 170) (192 . 171) (191 . 172) 
    (190 . 173) (189 . 174) (37 . 129) (7 . 175) (8 . 176) (9 . 177) (10 . 178
    ) (11 . 179) (38 . 180) (12 . 64) (39 . 65) (188 . 181) (187 . 182) 
    (209 . 183) (210 . 184) (211 . 185) (186 . 186) (89 . 187) (90 . 188) 
    (91 . 189) (92 . 190) (93 . 207) (94 . 192) (106 . 193) (206 . 194) 
    (185 . 195) (95 . 196) (196 . 197) (97 . 198) (98 . 199) (205 . 200) 
    (197 . 201) (184 . 202) (104 . 208) (201 . 209) (171 . 210)) ((106 . 206))
    ((72 . 205) (1 . -96)) ((102 . 139) (106 . 140) (1 . -214)) ((57 . 166) 
    (101 . 167) (195 . 168) (194 . 169) (193 . 170) (192 . 171) (191 . 172) 
    (190 . 173) (189 . 174) (37 . 129) (7 . 175) (8 . 176) (9 . 177) (10 . 178
    ) (11 . 179) (38 . 180) (12 . 64) (39 . 65) (188 . 181) (187 . 182) 
    (209 . 183) (210 . 184) (211 . 185) (186 . 186) (89 . 187) (90 . 188) 
    (91 . 189) (92 . 190) (93 . 191) (94 . 192) (106 . 193) (206 . 194) 
    (185 . 195) (95 . 196) (196 . 197) (97 . 198) (98 . 199) (205 . 200) 
    (197 . 201) (184 . 202) (201 . 203) (31 . 18) (32 . 19) (33 . 20) (176 . 
    142) (143 . 204)) ((105 . 159) (12 . 64) (39 . 65) (211 . 160) (141 . 161)
    (27 . 3) (34 . 4) (35 . 5) (36 . 6) (44 . 7) (45 . 8) (46 . 9) (47 . 10) 
    (48 . 11) (49 . 12) (51 . 13) (50 . 14) (53 . 15) (29 . 16) (30 . 17) 
    (31 . 18) (32 . 19) (33 . 20) (165 . 24) (166 . 25) (167 . 26) (168 . 27) 
    (54 . 28) (169 . 29) (170 . 30) (55 . 31) (56 . 32) (57 . 33) (58 . 34) 
    (59 . 56) (60 . 35) (175 . 38) (176 . 39) (177 . 40) (178 . 41) (199 . 162
    ) (139 . 163) (140 . 164) (142 . 165)) ((105 . 158)) ((1 . -233)) (
    (31 . 18) (32 . 19) (33 . 20) (176 . 156) (93 . 66) (145 . 157) (1 . -230)
    ) ((1 . -231)) ((5 . -365) (1 . -365)) ((5 . -354) (1 . -354)) ((5 . -83) 
    (1 . -83)) ((40 . 21) (41 . 22) (42 . 23) (161 . 36) (43 . 37) (164 . 59) 
    (1 . -170)) ((180 . 155) (61 . -84)) ((12 . 64) (39 . 65) (93 . 66) 
    (106 . 67) (211 . 68) (144 . 69) (145 . 70) (173 . 152) (174 . 154)) 
    ((112 . 153) (5 . -347) (1 . -347)) ((72 . 135) (13 . 136) (172 . 137) 
    (1 . -95)) ((116 . 391) (5 . -337) (1 . -337)) ((1 . -94)) ((61 . 390)) 
    ((1 . -234)) ((1 . -229)) ((1 . -217)) ((1 . -228)) ((105 . -242) (96 . 
    -242)) ((105 . 388) (96 . 389)) ((12 . 64) (39 . 65) (211 . 68) (144 . 69)
    (173 . 382) (102 . 383) (106 . 384) (93 . 66) (138 . 385) (145 . 386) 
    (198 . 387) (105 . -241) (96 . -241)) ((96 . -237) (105 . -237)) ((96 . 
    381) (105 . -235)) ((105 . 380)) ((31 . 18) (32 . 19) (33 . 20) (176 . 142
    ) (143 . 379)) ((1 . -221)) ((1 . -36)) ((93 . 376) (88 . 377) (87 . 378) 
    (1 . -40)) ((92 . 374) (91 . 375) (1 . -43)) ((86 . 372) (85 . 373) 
    (1 . -46)) ((84 . 368) (83 . 369) (82 . 370) (81 . 371) (1 . -51)) 
    ((80 . 366) (79 . 367) (1 . -54)) ((94 . 365) (1 . -56)) ((1 . -362)) 
    ((1 . -361)) ((1 . -360)) ((1 . -359)) ((1 . -358)) ((1 . -357)) ((78 . 
    364) (1 . -58)) ((77 . 363) (1 . -60)) ((37 . 243) (1 . -3)) ((1 . -2)) 
    ((1 . -1)) ((76 . 362) (1 . -62)) ((1 . -33)) ((1 . -32)) ((1 . -31)) 
    ((1 . -30)) ((101 . 361) (1 . -29)) ((1 . -28)) ((195 . 168) (194 . 169) 
    (193 . 170) (192 . 171) (191 . 172) (190 . 173) (189 . 174) (37 . 129) 
    (7 . 175) (8 . 176) (9 . 177) (10 . 178) (11 . 179) (38 . 180) (12 . 64) 
    (39 . 65) (188 . 181) (187 . 182) (209 . 183) (210 . 184) (211 . 185) 
    (186 . 186) (89 . 187) (90 . 188) (91 . 189) (92 . 190) (93 . 207) 
    (94 . 192) (106 . 193) (206 . 194) (185 . 195) (95 . 196) (196 . 197) 
    (97 . 198) (98 . 199) (205 . 200) (197 . 201) (184 . 202) (201 . 213) 
    (208 . 354) (104 . 355) (27 . 3) (34 . 4) (35 . 5) (36 . 6) (44 . 7) 
    (45 . 8) (46 . 9) (47 . 10) (48 . 11) (49 . 12) (51 . 13) (50 . 14) 
    (53 . 15) (29 . 16) (30 . 17) (31 . 18) (32 . 19) (33 . 20) (165 . 24) 
    (166 . 25) (167 . 26) (168 . 27) (54 . 28) (169 . 29) (170 . 30) (55 . 31)
    (56 . 32) (57 . 33) (58 . 34) (59 . 56) (60 . 35) (175 . 38) (176 . 356) 
    (177 . 357) (178 . 41) (199 . 358) (151 . 359) (203 . 360)) ((1 . -6)) 
    ((74 . 352) (75 . 353) (1 . -64)) ((37 . 129) (7 . 175) (8 . 176) (9 . 177
    ) (10 . 178) (11 . 179) (38 . 180) (12 . 64) (39 . 65) (209 . 183) 
    (210 . 184) (211 . 185) (89 . 187) (90 . 188) (91 . 189) (92 . 190) 
    (93 . 207) (94 . 192) (206 . 194) (95 . 196) (196 . 197) (97 . 198) 
    (98 . 199) (205 . 200) (197 . 350) (106 . 351)) ((37 . 129) (7 . 175) 
    (8 . 176) (9 . 177) (10 . 178) (11 . 179) (38 . 180) (12 . 64) (39 . 65) 
    (209 . 183) (210 . 184) (211 . 185) (89 . 187) (90 . 188) (91 . 189) 
    (92 . 190) (93 . 207) (94 . 192) (206 . 194) (95 . 196) (196 . 197) 
    (97 . 198) (98 . 199) (205 . 200) (106 . 193) (197 . 275) (195 . 349)) 
    ((37 . 129) (7 . 175) (8 . 176) (9 . 177) (10 . 178) (11 . 179) (38 . 180)
    (12 . 64) (39 . 65) (209 . 183) (210 . 184) (211 . 185) (89 . 187) 
    (90 . 188) (91 . 189) (92 . 190) (93 . 207) (94 . 192) (106 . 346) 
    (206 . 194) (95 . 196) (196 . 197) (97 . 198) (98 . 199) (205 . 200) 
    (197 . 348)) ((37 . 129) (7 . 175) (8 . 176) (9 . 177) (10 . 178) (11 . 
    179) (38 . 180) (12 . 64) (39 . 65) (209 . 183) (210 . 184) (211 . 185) 
    (89 . 187) (90 . 188) (91 . 189) (92 . 190) (93 . 207) (94 . 192) (106 . 
    346) (206 . 194) (95 . 196) (196 . 197) (97 . 198) (98 . 199) (205 . 200) 
    (197 . 347)) ((102 . 340) (106 . 341) (100 . 342) (99 . 343) (98 . 344) 
    (97 . 345) (1 . -22)) ((62 . 328) (63 . 329) (64 . 330) (65 . 331) 
    (66 . 332) (67 . 333) (68 . 334) (69 . 335) (70 . 336) (71 . 337) (72 . 
    338) (183 . 339) (1 . -34)) ((1 . -66)) ((101 . 327)) ((195 . 168) 
    (194 . 169) (193 . 170) (192 . 171) (191 . 172) (190 . 173) (189 . 174) 
    (37 . 129) (7 . 175) (8 . 176) (9 . 177) (10 . 178) (11 . 179) (38 . 180) 
    (12 . 64) (39 . 65) (188 . 181) (187 . 182) (209 . 183) (210 . 184) 
    (211 . 185) (186 . 186) (89 . 187) (90 . 188) (91 . 189) (92 . 190) 
    (94 . 192) (106 . 193) (206 . 194) (185 . 195) (95 . 196) (196 . 197) 
    (97 . 198) (98 . 199) (205 . 200) (197 . 201) (184 . 202) (201 . 323) 
    (31 . 18) (32 . 19) (33 . 20) (176 . 156) (101 . 324) (57 . 325) (93 . 326
    )) ((195 . 168) (194 . 169) (193 . 170) (192 . 171) (191 . 172) (190 . 173
    ) (189 . 174) (37 . 129) (7 . 175) (8 . 176) (9 . 177) (10 . 178) (11 . 
    179) (38 . 180) (12 . 64) (39 . 65) (188 . 181) (187 . 182) (209 . 183) 
    (210 . 184) (211 . 185) (186 . 186) (89 . 187) (90 . 188) (91 . 189) 
    (92 . 190) (93 . 207) (94 . 192) (106 . 193) (206 . 194) (185 . 195) 
    (95 . 196) (196 . 197) (97 . 198) (98 . 199) (205 . 200) (197 . 201) 
    (184 . 202) (104 . 208) (201 . 209) (171 . 322)) ((37 . 129) (209 . 321)) 
    ((1 . -29)) ((195 . 168) (194 . 169) (193 . 170) (192 . 171) (191 . 172) 
    (190 . 173) (189 . 174) (37 . 129) (7 . 175) (8 . 176) (9 . 177) (10 . 178
    ) (11 . 179) (38 . 180) (12 . 64) (39 . 65) (188 . 181) (187 . 182) 
    (209 . 183) (210 . 184) (211 . 185) (186 . 186) (89 . 187) (90 . 188) 
    (91 . 189) (92 . 190) (93 . 207) (94 . 192) (106 . 193) (206 . 194) 
    (100 . 314) (102 . 315) (185 . 195) (95 . 196) (196 . 197) (97 . 198) 
    (98 . 199) (205 . 200) (135 . 316) (197 . 201) (184 . 202) (136 . 317) 
    (104 . 208) (201 . 209) (171 . 318) (137 . 319) (202 . 320)) ((1 . -271)) 
    ((1 . -97)) ((5 . -349) (1 . -349)) ((1 . -352)) ((1 . -79)) ((61 . 313)) 
    ((195 . 168) (194 . 169) (193 . 170) (192 . 171) (191 . 172) (190 . 173) 
    (189 . 174) (37 . 129) (7 . 175) (8 . 176) (9 . 177) (10 . 178) (11 . 179)
    (38 . 180) (12 . 64) (39 . 65) (188 . 181) (187 . 182) (209 . 183) 
    (210 . 184) (211 . 185) (186 . 186) (89 . 187) (90 . 188) (91 . 189) 
    (92 . 190) (93 . 207) (94 . 192) (106 . 193) (206 . 194) (185 . 195) 
    (95 . 196) (196 . 197) (97 . 198) (98 . 199) (205 . 200) (197 . 201) 
    (184 . 202) (201 . 213) (208 . 311) (61 . 312)) ((61 . 310)) ((61 . 309)) 
    ((12 . 64) (39 . 65) (211 . 308)) ((106 . 307)) ((195 . 168) (194 . 169) 
    (193 . 170) (192 . 171) (191 . 172) (190 . 173) (189 . 174) (37 . 129) 
    (7 . 175) (8 . 176) (9 . 177) (10 . 178) (11 . 179) (38 . 180) (188 . 181)
    (187 . 182) (209 . 183) (210 . 184) (186 . 186) (89 . 187) (90 . 188) 
    (91 . 189) (92 . 190) (93 . 207) (94 . 192) (106 . 193) (206 . 194) 
    (185 . 195) (95 . 196) (196 . 197) (97 . 198) (98 . 199) (205 . 200) 
    (197 . 201) (184 . 202) (12 . 64) (39 . 65) (13 . 136) (201 . 213) 
    (4 . 43) (172 . 214) (14 . 215) (15 . 216) (16 . 217) (17 . 218) (18 . 219
    ) (19 . 220) (20 . 221) (21 . 222) (24 . 223) (61 . 224) (208 . 225) 
    (104 . 131) (25 . 226) (26 . 227) (211 . 228) (127 . 229) (128 . 230) 
    (129 . 231) (130 . 232) (131 . 233) (132 . 234) (133 . 235) (134 . 236) 
    (126 . 306)) ((106 . 305)) ((106 . 304)) ((106 . 303)) ((1 . -301)) 
    ((61 . 301) (96 . 302)) ((73 . 300)) ((37 . 129) (7 . 175) (8 . 176) 
    (9 . 177) (10 . 178) (11 . 179) (38 . 180) (12 . 64) (39 . 65) (209 . 183)
    (210 . 184) (211 . 185) (89 . 187) (90 . 188) (91 . 189) (92 . 190) 
    (93 . 207) (94 . 192) (206 . 194) (95 . 196) (196 . 197) (97 . 198) 
    (98 . 199) (205 . 200) (106 . 193) (197 . 275) (195 . 168) (194 . 169) 
    (193 . 170) (192 . 171) (191 . 172) (190 . 173) (189 . 174) (188 . 181) 
    (187 . 182) (186 . 186) (185 . 195) (184 . 276) (148 . 299)) ((73 . 298) 
    (1 . -1)) ((1 . -290)) ((1 . -289)) ((1 . -288)) ((1 . -287)) ((1 . -286))
    ((1 . -285)) ((1 . -284)) ((1 . -283)) ((1 . -299)) ((1 . -298)) ((1 . 
    -296)) ((103 . 296) (195 . 168) (194 . 169) (193 . 170) (192 . 171) 
    (191 . 172) (190 . 173) (189 . 174) (37 . 129) (7 . 175) (8 . 176) 
    (9 . 177) (10 . 178) (11 . 179) (38 . 180) (188 . 181) (187 . 182) 
    (209 . 183) (210 . 184) (186 . 186) (89 . 187) (90 . 188) (91 . 189) 
    (92 . 190) (93 . 207) (94 . 192) (106 . 193) (206 . 194) (185 . 195) 
    (95 . 196) (196 . 197) (97 . 198) (98 . 199) (205 . 200) (27 . 3) (34 . 4)
    (35 . 5) (36 . 6) (44 . 7) (45 . 8) (46 . 9) (47 . 10) (48 . 11) (49 . 12)
    (51 . 13) (50 . 14) (53 . 15) (197 . 201) (184 . 202) (12 . 64) (39 . 65) 
    (13 . 136) (29 . 16) (30 . 17) (31 . 18) (32 . 19) (33 . 20) (165 . 24) 
    (166 . 25) (167 . 26) (168 . 27) (54 . 28) (169 . 29) (170 . 30) (55 . 31)
    (56 . 32) (57 . 33) (58 . 34) (59 . 56) (60 . 35) (201 . 213) (4 . 43) 
    (172 . 214) (14 . 215) (15 . 216) (16 . 217) (17 . 218) (18 . 219) 
    (19 . 220) (20 . 221) (21 . 222) (24 . 223) (61 . 224) (208 . 225) 
    (104 . 131) (25 . 226) (26 . 227) (211 . 228) (175 . 38) (176 . 39) 
    (177 . 40) (178 . 41) (127 . 229) (128 . 230) (129 . 231) (130 . 232) 
    (131 . 233) (132 . 234) (133 . 235) (134 . 236) (199 . 57) (126 . 237) 
    (124 . 238) (125 . 297)) ((5 . -295) (1 . -295)) ((5 . -368) (1 . -368)) 
    ((1 . -364)) ((1 . -153)) ((1 . -152)) ((106 . 295) (105 . -158) (96 . 
    -158)) ((105 . -155) (96 . -155)) ((105 . 293) (96 . 294)) ((1 . -126)) 
    ((1 . -133)) ((40 . 21) (41 . 22) (42 . 23) (161 . 36) (43 . 37) (164 . 45
    ) (163 . 148) (181 . 292) (1 . -169)) ((5 . -185) (1 . -185)) ((5 . -186) 
    (1 . -186)) ((5 . -188) (1 . -188)) ((103 . 291) (27 . 3) (34 . 4) 
    (35 . 5) (36 . 6) (44 . 7) (45 . 8) (46 . 9) (47 . 10) (48 . 11) (49 . 12)
    (51 . 13) (50 . 14) (53 . 15) (31 . 18) (32 . 19) (33 . 20) (165 . 24) 
    (166 . 25) (167 . 26) (168 . 27) (54 . 28) (169 . 29) (170 . 30) (55 . 31)
    (176 . 109) (177 . 110) (151 . 111) (153 . 252) (5 . 44) (152 . 253) 
    (61 . 254)) ((27 . 3) (34 . 4) (35 . 5) (36 . 6) (44 . 7) (45 . 8) 
    (46 . 9) (47 . 10) (48 . 11) (49 . 12) (51 . 13) (50 . 14) (53 . 15) 
    (31 . 18) (32 . 19) (33 . 20) (165 . 24) (166 . 25) (167 . 26) (168 . 27) 
    (54 . 28) (169 . 29) (170 . 30) (55 . 31) (176 . 109) (177 . 110) (5 . 44)
    (151 . 111) (61 . 112) (152 . 113) (153 . 114) (154 . 290)) ((103 . 289) 
    (27 . 3) (34 . 4) (35 . 5) (36 . 6) (44 . 7) (45 . 8) (46 . 9) (47 . 10) 
    (48 . 11) (49 . 12) (51 . 13) (50 . 14) (53 . 15) (31 . 18) (32 . 19) 
    (33 . 20) (165 . 24) (166 . 25) (167 . 26) (168 . 27) (54 . 28) (169 . 29)
    (170 . 30) (55 . 31) (176 . 109) (177 . 110) (151 . 111) (153 . 252) 
    (5 . 44) (152 . 253) (61 . 254)) ((40 . 21) (41 . 22) (42 . 23) (161 . 36)
    (43 . 37) (164 . 45) (163 . 148) (181 . 288) (1 . -169)) ((37 . 129) 
    (7 . 175) (8 . 176) (9 . 177) (10 . 178) (11 . 179) (38 . 180) (12 . 64) 
    (39 . 65) (209 . 183) (210 . 184) (211 . 185) (89 . 187) (90 . 188) 
    (91 . 189) (92 . 190) (93 . 207) (94 . 192) (206 . 194) (95 . 196) 
    (196 . 197) (97 . 198) (98 . 199) (205 . 200) (106 . 193) (197 . 275) 
    (195 . 168) (194 . 169) (193 . 170) (192 . 171) (191 . 172) (190 . 173) 
    (189 . 174) (188 . 181) (187 . 182) (186 . 186) (185 . 195) (184 . 276) 
    (148 . 287)) ((73 . 286) (1 . -197)) ((1 . -195)) ((40 . 21) (41 . 22) 
    (42 . 23) (161 . 36) (43 . 37) (164 . 45) (163 . 148) (181 . 284) (96 . 
    285) (61 . -169)) ((6 . 145) (109 . 146) (179 . 283) (5 . -353) (1 . -353)
    ) ((1 . -191)) ((1 . -193)) ((103 . 282) (27 . 3) (34 . 4) (35 . 5) 
    (36 . 6) (44 . 7) (45 . 8) (46 . 9) (47 . 10) (48 . 11) (49 . 12) (51 . 13
    ) (50 . 14) (53 . 15) (31 . 18) (32 . 19) (33 . 20) (165 . 24) (166 . 25) 
    (167 . 26) (168 . 27) (54 . 28) (169 . 29) (170 . 30) (55 . 31) (176 . 109
    ) (177 . 110) (151 . 111) (153 . 252) (5 . 44) (152 . 253) (61 . 254)) 
    ((27 . 3) (34 . 4) (35 . 5) (36 . 6) (44 . 7) (45 . 8) (46 . 9) (47 . 10) 
    (48 . 11) (49 . 12) (51 . 13) (50 . 14) (53 . 15) (31 . 18) (32 . 19) 
    (33 . 20) (165 . 24) (166 . 25) (167 . 26) (168 . 27) (54 . 28) (169 . 29)
    (170 . 30) (55 . 31) (176 . 109) (177 . 110) (5 . 44) (151 . 111) (61 . 
    112) (152 . 113) (153 . 114) (154 . 281)) ((103 . 280) (27 . 3) (34 . 4) 
    (35 . 5) (36 . 6) (44 . 7) (45 . 8) (46 . 9) (47 . 10) (48 . 11) (49 . 12)
    (51 . 13) (50 . 14) (53 . 15) (31 . 18) (32 . 19) (33 . 20) (165 . 24) 
    (166 . 25) (167 . 26) (168 . 27) (54 . 28) (169 . 29) (170 . 30) (55 . 31)
    (176 . 109) (177 . 110) (151 . 111) (153 . 252) (5 . 44) (152 . 253) 
    (61 . 254)) ((1 . -202)) ((103 . 278) (12 . 64) (39 . 65) (211 . 103) 
    (146 . 279)) ((37 . 129) (7 . 175) (8 . 176) (9 . 177) (10 . 178) (11 . 
    179) (38 . 180) (12 . 64) (39 . 65) (209 . 183) (210 . 184) (211 . 185) 
    (89 . 187) (90 . 188) (91 . 189) (92 . 190) (93 . 207) (94 . 192) (206 . 
    194) (95 . 196) (196 . 197) (97 . 198) (98 . 199) (205 . 200) (106 . 193) 
    (197 . 275) (195 . 168) (194 . 169) (193 . 170) (192 . 171) (191 . 172) 
    (190 . 173) (189 . 174) (188 . 181) (187 . 182) (186 . 186) (185 . 195) 
    (184 . 276) (148 . 277)) ((96 . 273) (103 . 274)) ((12 . 64) (39 . 65) 
    (211 . 103) (146 . 279) (103 . 489)) ((1 . -200)) ((1 . -34)) ((1 . -81)) 
    ((103 . -208) (96 . -208)) ((1 . -203)) ((103 . -206) (96 . -206)) 
    ((1 . -180)) ((103 . 488) (27 . 3) (34 . 4) (35 . 5) (36 . 6) (44 . 7) 
    (45 . 8) (46 . 9) (47 . 10) (48 . 11) (49 . 12) (51 . 13) (50 . 14) 
    (53 . 15) (31 . 18) (32 . 19) (33 . 20) (165 . 24) (166 . 25) (167 . 26) 
    (168 . 27) (54 . 28) (169 . 29) (170 . 30) (55 . 31) (176 . 109) (177 . 
    110) (151 . 111) (153 . 252) (5 . 44) (152 . 253) (61 . 254)) ((40 . 21) 
    (41 . 22) (42 . 23) (161 . 36) (43 . 37) (164 . 45) (163 . 148) (181 . 487
    ) (1 . -169)) ((5 . -190) (1 . -190)) ((61 . 486)) ((12 . 64) (39 . 65) 
    (93 . 66) (106 . 67) (211 . 68) (144 . 69) (145 . 70) (73 . 259) (173 . 
    260) (149 . 485)) ((37 . 129) (7 . 175) (8 . 176) (9 . 177) (10 . 178) 
    (11 . 179) (38 . 180) (12 . 64) (39 . 65) (209 . 183) (210 . 184) (211 . 
    185) (89 . 187) (90 . 188) (91 . 189) (92 . 190) (93 . 207) (94 . 192) 
    (206 . 194) (95 . 196) (196 . 197) (97 . 198) (98 . 199) (205 . 200) 
    (106 . 193) (197 . 275) (195 . 168) (194 . 169) (193 . 170) (192 . 171) 
    (191 . 172) (190 . 173) (189 . 174) (188 . 181) (187 . 182) (186 . 186) 
    (185 . 195) (184 . 276) (148 . 484)) ((1 . -199)) ((1 . -175)) ((1 . -178)
    ) ((103 . 483) (27 . 3) (34 . 4) (35 . 5) (36 . 6) (44 . 7) (45 . 8) 
    (46 . 9) (47 . 10) (48 . 11) (49 . 12) (51 . 13) (50 . 14) (53 . 15) 
    (31 . 18) (32 . 19) (33 . 20) (165 . 24) (166 . 25) (167 . 26) (168 . 27) 
    (54 . 28) (169 . 29) (170 . 30) (55 . 31) (176 . 109) (177 . 110) (151 . 
    111) (153 . 252) (5 . 44) (152 . 253) (61 . 254)) ((40 . 21) (41 . 22) 
    (42 . 23) (161 . 36) (43 . 37) (164 . 45) (163 . 148) (181 . 482) (1 . 
    -169)) ((1 . -172)) ((105 . 481)) ((40 . 21) (41 . 22) (42 . 23) (39 . 244
    ) (161 . 245) (159 . 246) (160 . 480) (105 . -156) (96 . -156)) ((27 . 3) 
    (34 . 4) (35 . 5) (36 . 6) (44 . 7) (45 . 8) (46 . 9) (47 . 10) (48 . 11) 
    (49 . 12) (51 . 13) (50 . 14) (53 . 15) (29 . 16) (30 . 17) (31 . 18) 
    (32 . 19) (33 . 20) (165 . 24) (166 . 25) (167 . 26) (168 . 27) (54 . 28) 
    (169 . 29) (170 . 30) (55 . 31) (56 . 32) (57 . 33) (58 . 34) (59 . 56) 
    (60 . 35) (40 . 21) (41 . 22) (42 . 23) (175 . 38) (176 . 356) (177 . 357)
    (178 . 41) (199 . 358) (151 . 359) (161 . 472) (39 . 473) (156 . 474) 
    (37 . 475) (38 . 476) (203 . 477) (157 . 478) (158 . 479)) ((5 . -294) 
    (1 . -294)) ((1 . -297)) ((195 . 168) (194 . 169) (193 . 170) (192 . 171) 
    (191 . 172) (190 . 173) (189 . 174) (37 . 129) (7 . 175) (8 . 176) 
    (9 . 177) (10 . 178) (11 . 179) (38 . 180) (188 . 181) (187 . 182) 
    (209 . 183) (210 . 184) (186 . 186) (89 . 187) (90 . 188) (91 . 189) 
    (92 . 190) (93 . 207) (94 . 192) (106 . 193) (206 . 194) (185 . 195) 
    (95 . 196) (196 . 197) (97 . 198) (98 . 199) (205 . 200) (197 . 201) 
    (184 . 202) (12 . 64) (39 . 65) (13 . 136) (201 . 213) (4 . 43) (172 . 214
    ) (14 . 215) (15 . 216) (16 . 217) (17 . 218) (18 . 219) (19 . 220) 
    (20 . 221) (21 . 222) (24 . 223) (61 . 224) (208 . 225) (104 . 131) 
    (25 . 226) (26 . 227) (211 . 228) (127 . 229) (128 . 230) (129 . 231) 
    (130 . 232) (131 . 233) (132 . 234) (133 . 235) (134 . 236) (126 . 471)) 
    ((73 . 470)) ((195 . 168) (194 . 169) (193 . 170) (192 . 171) (191 . 172) 
    (190 . 173) (189 . 174) (37 . 129) (7 . 175) (8 . 176) (9 . 177) (10 . 178
    ) (11 . 179) (38 . 180) (188 . 181) (187 . 182) (209 . 183) (210 . 184) 
    (186 . 186) (89 . 187) (90 . 188) (91 . 189) (92 . 190) (93 . 207) 
    (94 . 192) (106 . 193) (206 . 194) (185 . 195) (95 . 196) (196 . 197) 
    (97 . 198) (98 . 199) (205 . 200) (197 . 201) (184 . 202) (12 . 64) 
    (39 . 65) (13 . 136) (201 . 213) (4 . 43) (172 . 214) (14 . 215) (15 . 216
    ) (16 . 217) (17 . 218) (18 . 219) (19 . 220) (20 . 221) (21 . 222) 
    (24 . 223) (61 . 224) (208 . 225) (104 . 131) (25 . 226) (26 . 227) 
    (211 . 228) (127 . 229) (128 . 230) (129 . 231) (130 . 232) (131 . 233) 
    (132 . 234) (133 . 235) (134 . 236) (126 . 469)) ((1 . -300)) ((195 . 168)
    (194 . 169) (193 . 170) (192 . 171) (191 . 172) (190 . 173) (189 . 174) 
    (37 . 129) (7 . 175) (8 . 176) (9 . 177) (10 . 178) (11 . 179) (38 . 180) 
    (12 . 64) (39 . 65) (188 . 181) (187 . 182) (209 . 183) (210 . 184) 
    (211 . 185) (186 . 186) (89 . 187) (90 . 188) (91 . 189) (92 . 190) 
    (93 . 207) (94 . 192) (106 . 193) (206 . 194) (185 . 195) (95 . 196) 
    (196 . 197) (97 . 198) (98 . 199) (205 . 200) (197 . 201) (184 . 202) 
    (201 . 468)) ((195 . 168) (194 . 169) (193 . 170) (192 . 171) (191 . 172) 
    (190 . 173) (189 . 174) (37 . 129) (7 . 175) (8 . 176) (9 . 177) (10 . 178
    ) (11 . 179) (38 . 180) (12 . 64) (39 . 65) (188 . 181) (187 . 182) 
    (209 . 183) (210 . 184) (211 . 185) (186 . 186) (89 . 187) (90 . 188) 
    (91 . 189) (92 . 190) (93 . 207) (94 . 192) (106 . 193) (206 . 194) 
    (185 . 195) (95 . 196) (196 . 197) (97 . 198) (98 . 199) (205 . 200) 
    (197 . 201) (184 . 202) (201 . 213) (208 . 467)) ((195 . 168) (194 . 169) 
    (193 . 170) (192 . 171) (191 . 172) (190 . 173) (189 . 174) (37 . 129) 
    (7 . 175) (8 . 176) (9 . 177) (10 . 178) (11 . 179) (38 . 180) (12 . 64) 
    (39 . 65) (188 . 181) (187 . 182) (209 . 183) (210 . 184) (211 . 185) 
    (186 . 186) (89 . 187) (90 . 188) (91 . 189) (92 . 190) (93 . 207) 
    (94 . 192) (106 . 193) (206 . 194) (185 . 195) (95 . 196) (196 . 197) 
    (97 . 198) (98 . 199) (205 . 200) (197 . 201) (184 . 202) (201 . 213) 
    (208 . 466)) ((195 . 168) (194 . 169) (193 . 170) (192 . 171) (191 . 172) 
    (190 . 173) (189 . 174) (37 . 129) (7 . 175) (8 . 176) (9 . 177) (10 . 178
    ) (11 . 179) (38 . 180) (12 . 64) (39 . 65) (188 . 181) (187 . 182) 
    (209 . 183) (210 . 184) (211 . 185) (186 . 186) (89 . 187) (90 . 188) 
    (91 . 189) (92 . 190) (93 . 207) (94 . 192) (106 . 193) (206 . 194) 
    (185 . 195) (95 . 196) (196 . 197) (97 . 198) (98 . 199) (205 . 200) 
    (197 . 201) (184 . 202) (201 . 213) (208 . 465)) ((20 . 464)) ((195 . 168)
    (194 . 169) (193 . 170) (192 . 171) (191 . 172) (190 . 173) (189 . 174) 
    (37 . 129) (7 . 175) (8 . 176) (9 . 177) (10 . 178) (11 . 179) (38 . 180) 
    (12 . 64) (39 . 65) (188 . 181) (187 . 182) (209 . 183) (210 . 184) 
    (211 . 185) (27 . 3) (34 . 4) (35 . 5) (36 . 6) (44 . 7) (45 . 8) (46 . 9)
    (47 . 10) (48 . 11) (49 . 12) (51 . 13) (50 . 14) (53 . 15) (186 . 186) 
    (89 . 187) (90 . 188) (91 . 189) (92 . 190) (93 . 207) (94 . 192) (106 . 
    193) (206 . 194) (29 . 16) (30 . 17) (31 . 18) (32 . 19) (33 . 20) 
    (165 . 24) (166 . 25) (167 . 26) (168 . 27) (54 . 28) (169 . 29) (170 . 30
    ) (55 . 31) (56 . 32) (57 . 33) (58 . 34) (59 . 56) (60 . 35) (185 . 195) 
    (95 . 196) (196 . 197) (97 . 198) (98 . 199) (205 . 200) (175 . 38) 
    (176 . 39) (177 . 40) (178 . 41) (197 . 201) (184 . 202) (199 . 57) 
    (201 . 213) (124 . 460) (61 . 461) (208 . 462) (123 . 463)) ((61 . 459)) 
    ((1 . -314)) ((1 . -315)) ((61 . 458) (96 . 302)) ((1 . -317)) ((1 . -318)
    ) ((12 . 64) (39 . 65) (211 . 457)) ((37 . 129) (7 . 175) (8 . 176) 
    (9 . 177) (10 . 178) (11 . 179) (38 . 180) (12 . 64) (39 . 65) (209 . 183)
    (210 . 184) (211 . 185) (89 . 187) (90 . 188) (91 . 189) (92 . 190) 
    (93 . 207) (94 . 192) (206 . 194) (95 . 196) (196 . 197) (97 . 198) 
    (98 . 199) (205 . 200) (106 . 193) (197 . 275) (195 . 168) (194 . 169) 
    (193 . 170) (192 . 171) (191 . 172) (190 . 173) (189 . 174) (188 . 181) 
    (187 . 182) (186 . 186) (185 . 195) (184 . 276) (148 . 456)) ((1 . -279)) 
    ((72 . 454) (100 . 314) (102 . 315) (135 . 455)) ((96 . -275) (103 . -275)
    ) ((195 . 168) (194 . 169) (193 . 170) (192 . 171) (191 . 172) (190 . 173)
    (189 . 174) (37 . 129) (7 . 175) (8 . 176) (9 . 177) (10 . 178) (11 . 179)
    (38 . 180) (12 . 64) (39 . 65) (188 . 181) (187 . 182) (209 . 183) 
    (210 . 184) (211 . 185) (186 . 186) (89 . 187) (90 . 188) (91 . 189) 
    (92 . 190) (93 . 207) (94 . 192) (106 . 193) (206 . 194) (185 . 195) 
    (95 . 196) (196 . 197) (97 . 198) (98 . 199) (205 . 200) (197 . 201) 
    (184 . 202) (104 . 208) (201 . 209) (171 . 453)) ((96 . 451) (103 . 452)) 
    ((105 . 448) (37 . 243) (73 . 449) (121 . 450)) ((1 . -98)) ((101 . 447)) 
    ((1 . -219)) ((195 . 168) (194 . 169) (193 . 170) (192 . 171) (191 . 172) 
    (190 . 173) (189 . 174) (37 . 129) (7 . 175) (8 . 176) (9 . 177) (10 . 178
    ) (11 . 179) (38 . 180) (12 . 64) (39 . 65) (188 . 181) (187 . 182) 
    (209 . 183) (210 . 184) (211 . 185) (186 . 186) (89 . 187) (90 . 188) 
    (91 . 189) (92 . 190) (93 . 207) (94 . 192) (106 . 193) (206 . 194) 
    (185 . 195) (95 . 196) (196 . 197) (97 . 198) (98 . 199) (205 . 200) 
    (197 . 201) (184 . 202) (201 . 446)) ((101 . 445) (1 . -29)) ((1 . -220)) 
    ((1 . -78)) ((1 . -77)) ((1 . -76)) ((1 . -75)) ((1 . -74)) ((1 . -73)) 
    ((1 . -72)) ((1 . -71)) ((1 . -70)) ((1 . -69)) ((1 . -68)) ((195 . 168) 
    (194 . 169) (193 . 170) (192 . 171) (191 . 172) (190 . 173) (189 . 174) 
    (37 . 129) (7 . 175) (8 . 176) (9 . 177) (10 . 178) (11 . 179) (38 . 180) 
    (12 . 64) (39 . 65) (188 . 181) (187 . 182) (209 . 183) (210 . 184) 
    (211 . 185) (186 . 186) (89 . 187) (90 . 188) (91 . 189) (92 . 190) 
    (93 . 207) (94 . 192) (106 . 193) (206 . 194) (185 . 195) (95 . 196) 
    (196 . 197) (97 . 198) (98 . 199) (205 . 200) (197 . 201) (184 . 202) 
    (201 . 444)) ((195 . 168) (194 . 169) (193 . 170) (192 . 171) (191 . 172) 
    (190 . 173) (189 . 174) (37 . 129) (7 . 175) (8 . 176) (9 . 177) (10 . 178
    ) (11 . 179) (38 . 180) (12 . 64) (39 . 65) (188 . 181) (187 . 182) 
    (209 . 183) (210 . 184) (211 . 185) (186 . 186) (89 . 187) (90 . 188) 
    (91 . 189) (92 . 190) (93 . 207) (94 . 192) (106 . 193) (206 . 194) 
    (185 . 195) (95 . 196) (196 . 197) (97 . 198) (98 . 199) (205 . 200) 
    (197 . 201) (184 . 202) (201 . 213) (208 . 443)) ((105 . 438) (195 . 168) 
    (194 . 169) (193 . 170) (192 . 171) (191 . 172) (190 . 173) (189 . 174) 
    (37 . 129) (7 . 175) (8 . 176) (9 . 177) (10 . 178) (11 . 179) (38 . 180) 
    (12 . 64) (39 . 65) (188 . 181) (27 . 3) (34 . 4) (35 . 5) (36 . 6) 
    (44 . 7) (45 . 8) (46 . 9) (47 . 10) (48 . 11) (49 . 12) (51 . 13) 
    (50 . 14) (53 . 15) (187 . 182) (209 . 183) (210 . 184) (211 . 185) 
    (29 . 16) (30 . 17) (31 . 18) (32 . 19) (33 . 20) (165 . 24) (166 . 25) 
    (167 . 26) (168 . 27) (54 . 28) (169 . 29) (170 . 30) (55 . 31) (56 . 32) 
    (57 . 33) (58 . 34) (59 . 56) (60 . 35) (186 . 186) (89 . 187) (90 . 188) 
    (91 . 189) (92 . 190) (93 . 207) (94 . 192) (106 . 193) (206 . 194) 
    (175 . 38) (176 . 39) (177 . 40) (178 . 41) (185 . 195) (95 . 196) 
    (196 . 197) (97 . 198) (98 . 199) (205 . 200) (197 . 201) (184 . 202) 
    (199 . 439) (200 . 440) (201 . 441) (204 . 442)) ((12 . 64) (39 . 65) 
    (211 . 437)) ((12 . 64) (39 . 65) (211 . 436)) ((1 . -12)) ((1 . -13)) 
    ((27 . 3) (34 . 4) (35 . 5) (36 . 6) (44 . 7) (45 . 8) (46 . 9) (47 . 10) 
    (48 . 11) (49 . 12) (51 . 13) (50 . 14) (53 . 15) (29 . 16) (30 . 17) 
    (31 . 18) (32 . 19) (33 . 20) (165 . 24) (166 . 25) (167 . 26) (168 . 27) 
    (54 . 28) (169 . 29) (170 . 30) (55 . 31) (56 . 32) (57 . 33) (58 . 34) 
    (59 . 56) (60 . 35) (175 . 38) (176 . 356) (177 . 357) (178 . 41) (199 . 
    358) (151 . 359) (203 . 435) (195 . 168) (194 . 169) (193 . 170) (192 . 
    171) (191 . 172) (190 . 173) (189 . 174) (37 . 129) (7 . 175) (8 . 176) 
    (9 . 177) (10 . 178) (11 . 179) (38 . 180) (12 . 64) (39 . 65) (188 . 181)
    (187 . 182) (209 . 183) (210 . 184) (211 . 185) (186 . 186) (89 . 187) 
    (90 . 188) (91 . 189) (92 . 190) (93 . 207) (94 . 192) (106 . 193) 
    (206 . 194) (185 . 195) (95 . 196) (196 . 197) (97 . 198) (98 . 199) 
    (205 . 200) (197 . 201) (184 . 202) (201 . 213) (208 . 354) (104 . 355)) 
    ((1 . -23)) ((1 . -24)) ((1 . -25)) ((1 . -26)) ((27 . 3) (34 . 4) 
    (35 . 5) (36 . 6) (44 . 7) (45 . 8) (46 . 9) (47 . 10) (48 . 11) (49 . 12)
    (51 . 13) (50 . 14) (53 . 15) (29 . 16) (30 . 17) (31 . 18) (32 . 19) 
    (33 . 20) (165 . 24) (166 . 25) (167 . 26) (168 . 27) (54 . 28) (169 . 29)
    (170 . 30) (55 . 31) (56 . 32) (57 . 33) (58 . 34) (59 . 56) (60 . 35) 
    (175 . 38) (176 . 356) (177 . 357) (178 . 41) (199 . 358) (151 . 359) 
    (203 . 434) (195 . 168) (194 . 169) (193 . 170) (192 . 171) (191 . 172) 
    (190 . 173) (189 . 174) (37 . 129) (7 . 175) (8 . 176) (9 . 177) (10 . 178
    ) (11 . 179) (38 . 180) (12 . 64) (39 . 65) (188 . 181) (187 . 182) 
    (209 . 183) (210 . 184) (211 . 185) (186 . 186) (89 . 187) (90 . 188) 
    (91 . 189) (92 . 190) (93 . 207) (94 . 192) (106 . 193) (206 . 194) 
    (185 . 195) (95 . 196) (196 . 197) (97 . 198) (98 . 199) (205 . 200) 
    (197 . 201) (184 . 202) (201 . 213) (208 . 354) (104 . 355)) ((195 . 168) 
    (194 . 169) (193 . 170) (192 . 171) (191 . 172) (190 . 173) (189 . 174) 
    (37 . 129) (7 . 175) (8 . 176) (9 . 177) (10 . 178) (11 . 179) (38 . 180) 
    (12 . 64) (39 . 65) (188 . 181) (187 . 182) (209 . 183) (210 . 184) 
    (211 . 185) (186 . 186) (89 . 187) (90 . 188) (91 . 189) (92 . 190) 
    (93 . 207) (94 . 192) (106 . 193) (206 . 194) (185 . 195) (95 . 196) 
    (196 . 197) (97 . 198) (98 . 199) (205 . 200) (197 . 201) (184 . 202) 
    (201 . 213) (208 . 433)) ((37 . 129) (7 . 175) (8 . 176) (9 . 177) 
    (10 . 178) (11 . 179) (38 . 180) (12 . 64) (39 . 65) (209 . 183) (210 . 
    184) (211 . 185) (89 . 187) (90 . 188) (91 . 189) (92 . 190) (93 . 207) 
    (94 . 192) (206 . 194) (95 . 196) (196 . 197) (97 . 198) (98 . 199) 
    (205 . 200) (106 . 193) (197 . 275) (195 . 168) (194 . 169) (193 . 170) 
    (192 . 171) (191 . 172) (190 . 173) (189 . 174) (188 . 181) (187 . 182) 
    (186 . 432)) ((105 . 431) (96 . 302)) ((195 . 168) (194 . 169) (193 . 170)
    (192 . 171) (191 . 172) (190 . 173) (189 . 174) (37 . 129) (7 . 175) 
    (8 . 176) (9 . 177) (10 . 178) (11 . 179) (38 . 180) (188 . 181) (187 . 
    182) (209 . 183) (210 . 184) (186 . 186) (89 . 187) (90 . 188) (91 . 189) 
    (92 . 190) (93 . 207) (94 . 192) (106 . 193) (206 . 194) (185 . 195) 
    (95 . 196) (196 . 197) (97 . 198) (98 . 199) (205 . 200) (27 . 3) (34 . 4)
    (35 . 5) (36 . 6) (44 . 7) (45 . 8) (46 . 9) (47 . 10) (48 . 11) (49 . 12)
    (51 . 13) (50 . 14) (53 . 15) (197 . 201) (184 . 202) (12 . 64) (39 . 65) 
    (13 . 136) (29 . 16) (30 . 17) (31 . 18) (32 . 19) (33 . 20) (165 . 24) 
    (166 . 25) (167 . 26) (168 . 27) (54 . 28) (169 . 29) (170 . 30) (55 . 31)
    (56 . 32) (57 . 33) (58 . 34) (59 . 56) (60 . 35) (201 . 213) (4 . 43) 
    (172 . 214) (14 . 215) (15 . 216) (16 . 217) (17 . 218) (18 . 219) 
    (19 . 220) (20 . 221) (21 . 222) (24 . 223) (61 . 224) (208 . 225) 
    (104 . 131) (25 . 226) (26 . 227) (211 . 228) (175 . 38) (176 . 39) 
    (177 . 40) (178 . 41) (127 . 229) (128 . 230) (129 . 231) (130 . 232) 
    (131 . 233) (132 . 234) (133 . 235) (134 . 236) (199 . 57) (126 . 237) 
    (124 . 238) (125 . 239) (207 . 430)) ((29 . 16) (30 . 17) (56 . 32) 
    (57 . 33) (58 . 34) (59 . 56) (60 . 35) (175 . 38) (178 . 41) (199 . 75) 
    (27 . 3) (34 . 4) (35 . 5) (36 . 6) (44 . 7) (45 . 8) (46 . 9) (47 . 10) 
    (48 . 11) (49 . 12) (51 . 13) (50 . 14) (53 . 15) (31 . 18) (32 . 19) 
    (33 . 20) (165 . 24) (166 . 25) (167 . 26) (168 . 27) (54 . 28) (169 . 29)
    (170 . 30) (55 . 31) (176 . 356) (177 . 357) (151 . 265) (105 . -89) 
    (96 . -89) (1 . -194)) ((29 . 16) (30 . 17) (56 . 32) (57 . 33) (58 . 34) 
    (59 . 56) (60 . 35) (175 . 38) (178 . 41) (199 . 74) (27 . 3) (34 . 4) 
    (35 . 5) (36 . 6) (44 . 7) (45 . 8) (46 . 9) (47 . 10) (48 . 11) (49 . 12)
    (51 . 13) (50 . 14) (53 . 15) (31 . 18) (32 . 19) (33 . 20) (165 . 24) 
    (166 . 25) (167 . 26) (168 . 27) (54 . 28) (169 . 29) (170 . 30) (55 . 31)
    (176 . 356) (177 . 357) (151 . 264) (105 . -87) (96 . -87) (1 . -192)) 
    ((105 . -245) (96 . -245)) ((102 . 383) (106 . 427) (93 . 66) (138 . 385) 
    (145 . 428) (198 . 429)) ((105 . 426)) ((1 . -225)) ((37 . 129) (7 . 175) 
    (8 . 176) (9 . 177) (10 . 178) (11 . 179) (38 . 180) (12 . 64) (39 . 65) 
    (209 . 183) (210 . 184) (211 . 185) (89 . 187) (90 . 188) (91 . 189) 
    (92 . 190) (93 . 207) (94 . 192) (206 . 194) (95 . 196) (196 . 197) 
    (97 . 198) (98 . 199) (205 . 200) (106 . 193) (197 . 275) (195 . 168) 
    (194 . 169) (193 . 170) (192 . 171) (191 . 172) (190 . 173) (189 . 174) 
    (188 . 181) (187 . 425)) ((37 . 129) (7 . 175) (8 . 176) (9 . 177) 
    (10 . 178) (11 . 179) (38 . 180) (12 . 64) (39 . 65) (209 . 183) (210 . 
    184) (211 . 185) (89 . 187) (90 . 188) (91 . 189) (92 . 190) (93 . 207) 
    (94 . 192) (206 . 194) (95 . 196) (196 . 197) (97 . 198) (98 . 199) 
    (205 . 200) (106 . 193) (197 . 275) (195 . 168) (194 . 169) (193 . 170) 
    (192 . 171) (191 . 172) (190 . 173) (189 . 174) (188 . 424)) ((37 . 129) 
    (7 . 175) (8 . 176) (9 . 177) (10 . 178) (11 . 179) (38 . 180) (12 . 64) 
    (39 . 65) (209 . 183) (210 . 184) (211 . 185) (89 . 187) (90 . 188) 
    (91 . 189) (92 . 190) (93 . 207) (94 . 192) (206 . 194) (95 . 196) 
    (196 . 197) (97 . 198) (98 . 199) (205 . 200) (106 . 193) (197 . 275) 
    (195 . 168) (194 . 169) (193 . 170) (192 . 171) (191 . 172) (190 . 173) 
    (189 . 423)) ((37 . 129) (7 . 175) (8 . 176) (9 . 177) (10 . 178) (11 . 
    179) (38 . 180) (12 . 64) (39 . 65) (209 . 183) (210 . 184) (211 . 185) 
    (89 . 187) (90 . 188) (91 . 189) (92 . 190) (93 . 207) (94 . 192) (206 . 
    194) (95 . 196) (196 . 197) (97 . 198) (98 . 199) (205 . 200) (106 . 193) 
    (197 . 275) (195 . 168) (194 . 169) (193 . 170) (192 . 171) (191 . 172) 
    (190 . 422)) ((37 . 129) (7 . 175) (8 . 176) (9 . 177) (10 . 178) (11 . 
    179) (38 . 180) (12 . 64) (39 . 65) (209 . 183) (210 . 184) (211 . 185) 
    (89 . 187) (90 . 188) (91 . 189) (92 . 190) (93 . 207) (94 . 192) (206 . 
    194) (95 . 196) (196 . 197) (97 . 198) (98 . 199) (205 . 200) (106 . 193) 
    (197 . 275) (195 . 168) (194 . 169) (193 . 170) (192 . 171) (191 . 421)) 
    ((37 . 129) (7 . 175) (8 . 176) (9 . 177) (10 . 178) (11 . 179) (38 . 180)
    (12 . 64) (39 . 65) (209 . 183) (210 . 184) (211 . 185) (89 . 187) 
    (90 . 188) (91 . 189) (92 . 190) (93 . 207) (94 . 192) (206 . 194) 
    (95 . 196) (196 . 197) (97 . 198) (98 . 199) (205 . 200) (106 . 193) 
    (197 . 275) (195 . 168) (194 . 169) (193 . 170) (192 . 171) (191 . 420)) 
    ((37 . 129) (7 . 175) (8 . 176) (9 . 177) (10 . 178) (11 . 179) (38 . 180)
    (12 . 64) (39 . 65) (209 . 183) (210 . 184) (211 . 185) (89 . 187) 
    (90 . 188) (91 . 189) (92 . 190) (93 . 207) (94 . 192) (206 . 194) 
    (95 . 196) (196 . 197) (97 . 198) (98 . 199) (205 . 200) (106 . 193) 
    (197 . 275) (195 . 168) (194 . 169) (193 . 170) (192 . 419)) ((37 . 129) 
    (7 . 175) (8 . 176) (9 . 177) (10 . 178) (11 . 179) (38 . 180) (12 . 64) 
    (39 . 65) (209 . 183) (210 . 184) (211 . 185) (89 . 187) (90 . 188) 
    (91 . 189) (92 . 190) (93 . 207) (94 . 192) (206 . 194) (95 . 196) 
    (196 . 197) (97 . 198) (98 . 199) (205 . 200) (106 . 193) (197 . 275) 
    (195 . 168) (194 . 169) (193 . 170) (192 . 418)) ((37 . 129) (7 . 175) 
    (8 . 176) (9 . 177) (10 . 178) (11 . 179) (38 . 180) (12 . 64) (39 . 65) 
    (209 . 183) (210 . 184) (211 . 185) (89 . 187) (90 . 188) (91 . 189) 
    (92 . 190) (93 . 207) (94 . 192) (206 . 194) (95 . 196) (196 . 197) 
    (97 . 198) (98 . 199) (205 . 200) (106 . 193) (197 . 275) (195 . 168) 
    (194 . 169) (193 . 170) (192 . 417)) ((37 . 129) (7 . 175) (8 . 176) 
    (9 . 177) (10 . 178) (11 . 179) (38 . 180) (12 . 64) (39 . 65) (209 . 183)
    (210 . 184) (211 . 185) (89 . 187) (90 . 188) (91 . 189) (92 . 190) 
    (93 . 207) (94 . 192) (206 . 194) (95 . 196) (196 . 197) (97 . 198) 
    (98 . 199) (205 . 200) (106 . 193) (197 . 275) (195 . 168) (194 . 169) 
    (193 . 170) (192 . 416)) ((37 . 129) (7 . 175) (8 . 176) (9 . 177) 
    (10 . 178) (11 . 179) (38 . 180) (12 . 64) (39 . 65) (209 . 183) (210 . 
    184) (211 . 185) (89 . 187) (90 . 188) (91 . 189) (92 . 190) (93 . 207) 
    (94 . 192) (206 . 194) (95 . 196) (196 . 197) (97 . 198) (98 . 199) 
    (205 . 200) (106 . 193) (197 . 275) (195 . 168) (194 . 169) (193 . 415)) 
    ((37 . 129) (7 . 175) (8 . 176) (9 . 177) (10 . 178) (11 . 179) (38 . 180)
    (12 . 64) (39 . 65) (209 . 183) (210 . 184) (211 . 185) (89 . 187) 
    (90 . 188) (91 . 189) (92 . 190) (93 . 207) (94 . 192) (206 . 194) 
    (95 . 196) (196 . 197) (97 . 198) (98 . 199) (205 . 200) (106 . 193) 
    (197 . 275) (195 . 168) (194 . 169) (193 . 414)) ((37 . 129) (7 . 175) 
    (8 . 176) (9 . 177) (10 . 178) (11 . 179) (38 . 180) (12 . 64) (39 . 65) 
    (209 . 183) (210 . 184) (211 . 185) (89 . 187) (90 . 188) (91 . 189) 
    (92 . 190) (93 . 207) (94 . 192) (206 . 194) (95 . 196) (196 . 197) 
    (97 . 198) (98 . 199) (205 . 200) (106 . 193) (197 . 275) (195 . 168) 
    (194 . 413)) ((37 . 129) (7 . 175) (8 . 176) (9 . 177) (10 . 178) (11 . 
    179) (38 . 180) (12 . 64) (39 . 65) (209 . 183) (210 . 184) (211 . 185) 
    (89 . 187) (90 . 188) (91 . 189) (92 . 190) (93 . 207) (94 . 192) (206 . 
    194) (95 . 196) (196 . 197) (97 . 198) (98 . 199) (205 . 200) (106 . 193) 
    (197 . 275) (195 . 168) (194 . 412)) ((37 . 129) (7 . 175) (8 . 176) 
    (9 . 177) (10 . 178) (11 . 179) (38 . 180) (12 . 64) (39 . 65) (209 . 183)
    (210 . 184) (211 . 185) (89 . 187) (90 . 188) (91 . 189) (92 . 190) 
    (93 . 207) (94 . 192) (206 . 194) (95 . 196) (196 . 197) (97 . 198) 
    (98 . 199) (205 . 200) (106 . 193) (197 . 275) (195 . 411)) ((37 . 129) 
    (7 . 175) (8 . 176) (9 . 177) (10 . 178) (11 . 179) (38 . 180) (12 . 64) 
    (39 . 65) (209 . 183) (210 . 184) (211 . 185) (89 . 187) (90 . 188) 
    (91 . 189) (92 . 190) (93 . 207) (94 . 192) (206 . 194) (95 . 196) 
    (196 . 197) (97 . 198) (98 . 199) (205 . 200) (106 . 193) (197 . 275) 
    (195 . 410)) ((37 . 129) (7 . 175) (8 . 176) (9 . 177) (10 . 178) (11 . 
    179) (38 . 180) (12 . 64) (39 . 65) (209 . 183) (210 . 184) (211 . 185) 
    (89 . 187) (90 . 188) (91 . 189) (92 . 190) (93 . 207) (94 . 192) (206 . 
    194) (95 . 196) (196 . 197) (97 . 198) (98 . 199) (205 . 200) (106 . 193) 
    (197 . 275) (195 . 409)) ((195 . 168) (194 . 169) (193 . 170) (192 . 171) 
    (191 . 172) (190 . 173) (189 . 174) (37 . 129) (7 . 175) (8 . 176) 
    (9 . 177) (10 . 178) (11 . 179) (38 . 180) (12 . 64) (39 . 65) (188 . 181)
    (187 . 182) (209 . 183) (210 . 184) (211 . 185) (186 . 186) (89 . 187) 
    (90 . 188) (91 . 189) (92 . 190) (93 . 207) (94 . 192) (106 . 193) 
    (206 . 194) (185 . 195) (95 . 196) (196 . 197) (97 . 198) (98 . 199) 
    (205 . 200) (197 . 201) (184 . 202) (201 . 408) (31 . 18) (32 . 19) 
    (33 . 20) (176 . 156)) ((1 . -226)) ((27 . 3) (34 . 4) (35 . 5) (36 . 6) 
    (44 . 7) (45 . 8) (46 . 9) (47 . 10) (48 . 11) (49 . 12) (51 . 13) 
    (50 . 14) (53 . 15) (29 . 16) (30 . 17) (31 . 18) (32 . 19) (33 . 20) 
    (165 . 24) (166 . 25) (167 . 26) (168 . 27) (54 . 28) (169 . 29) (170 . 30
    ) (55 . 31) (56 . 32) (57 . 33) (58 . 34) (59 . 56) (60 . 35) (175 . 38) 
    (176 . 39) (177 . 40) (178 . 41) (199 . 162) (139 . 406) (28 . 407)) 
    ((105 . -239) (96 . -239)) ((195 . 168) (194 . 169) (193 . 170) (192 . 171
    ) (191 . 172) (190 . 173) (189 . 174) (37 . 129) (7 . 175) (8 . 176) 
    (9 . 177) (10 . 178) (11 . 179) (38 . 180) (12 . 64) (39 . 65) (188 . 181)
    (187 . 182) (209 . 183) (210 . 184) (211 . 185) (186 . 186) (89 . 187) 
    (90 . 188) (91 . 189) (92 . 190) (94 . 192) (106 . 193) (206 . 194) 
    (185 . 195) (95 . 196) (196 . 197) (97 . 198) (98 . 199) (205 . 200) 
    (197 . 201) (184 . 202) (201 . 401) (101 . 402) (57 . 403) (31 . 18) 
    (32 . 19) (33 . 20) (176 . 142) (143 . 404) (93 . 405)) ((102 . 383) 
    (138 . 385) (198 . 398) (27 . 3) (34 . 4) (35 . 5) (36 . 6) (44 . 7) 
    (45 . 8) (46 . 9) (47 . 10) (48 . 11) (49 . 12) (51 . 13) (50 . 14) 
    (53 . 15) (29 . 16) (30 . 17) (31 . 18) (32 . 19) (33 . 20) (165 . 24) 
    (166 . 25) (167 . 26) (168 . 27) (54 . 28) (169 . 29) (170 . 30) (55 . 31)
    (56 . 32) (57 . 33) (58 . 34) (59 . 56) (60 . 35) (175 . 38) (176 . 39) 
    (177 . 40) (178 . 41) (199 . 162) (139 . 163) (140 . 164) (142 . 399) 
    (105 . 400) (12 . 64) (39 . 65) (93 . 66) (106 . 384) (211 . 68) (144 . 69
    ) (145 . 386) (173 . 141)) ((102 . 396) (106 . 397) (105 . -248) (96 . 
    -248)) ((102 . 383) (138 . 395) (12 . 64) (39 . 65) (106 . 384) (211 . 68)
    (144 . 138) (105 . -247) (96 . -247)) ((105 . -240) (96 . -240)) ((1 . 
    -227)) ((12 . 64) (39 . 65) (211 . 394)) ((6 . 145) (109 . 146) (179 . 393
    ) (5 . -353) (1 . -353)) ((111 . 392) (27 . 3) (34 . 4) (35 . 5) (36 . 6) 
    (44 . 7) (45 . 8) (46 . 9) (47 . 10) (48 . 11) (49 . 12) (51 . 13) 
    (50 . 14) (53 . 15) (29 . 16) (30 . 17) (31 . 18) (32 . 19) (33 . 20) 
    (40 . 21) (41 . 22) (42 . 23) (165 . 24) (166 . 25) (167 . 26) (168 . 27) 
    (54 . 28) (169 . 29) (170 . 30) (55 . 31) (56 . 32) (57 . 33) (58 . 34) 
    (60 . 35) (161 . 36) (43 . 37) (175 . 38) (176 . 39) (177 . 40) (178 . 41)
    (3 . 42) (4 . 43) (5 . 44) (164 . 45) (199 . 46) (61 . 47) (59 . 48) 
    (113 . 49) (127 . 50) (152 . 51) (163 . 52) (124 . 53) (114 . 54) (115 . 
    55) (103 . -348)) ((103 . 540)) ((5 . -82) (1 . -82)) ((105 . -243) 
    (96 . -243)) ((102 . 396) (106 . 397) (105 . -246) (96 . -246)) ((57 . 535
    ) (101 . 536) (195 . 168) (194 . 169) (193 . 170) (192 . 171) (191 . 172) 
    (190 . 173) (189 . 174) (37 . 129) (7 . 175) (8 . 176) (9 . 177) (10 . 178
    ) (11 . 179) (38 . 180) (12 . 64) (39 . 65) (188 . 181) (187 . 182) 
    (209 . 183) (210 . 184) (211 . 185) (186 . 186) (89 . 187) (90 . 188) 
    (91 . 189) (92 . 190) (93 . 537) (94 . 192) (106 . 193) (206 . 194) 
    (185 . 195) (95 . 196) (196 . 197) (97 . 198) (98 . 199) (205 . 200) 
    (197 . 201) (184 . 202) (201 . 538) (31 . 18) (32 . 19) (33 . 20) (176 . 
    142) (143 . 539)) ((105 . 533) (27 . 3) (34 . 4) (35 . 5) (36 . 6) 
    (44 . 7) (45 . 8) (46 . 9) (47 . 10) (48 . 11) (49 . 12) (51 . 13) 
    (50 . 14) (53 . 15) (29 . 16) (30 . 17) (31 . 18) (32 . 19) (33 . 20) 
    (165 . 24) (166 . 25) (167 . 26) (168 . 27) (54 . 28) (169 . 29) (170 . 30
    ) (55 . 31) (56 . 32) (57 . 33) (58 . 34) (59 . 56) (60 . 35) (175 . 38) 
    (176 . 39) (177 . 40) (178 . 41) (199 . 162) (139 . 163) (140 . 164) 
    (142 . 534)) ((105 . 532)) ((105 . 531)) ((1 . -269)) ((101 . 530)) 
    ((1 . -260)) ((31 . 18) (32 . 19) (33 . 20) (176 . 142) (143 . 529)) 
    ((57 . 526) (31 . 18) (32 . 19) (33 . 20) (176 . 156) (101 . 527) (195 . 
    168) (194 . 169) (193 . 170) (192 . 171) (191 . 172) (190 . 173) (189 . 
    174) (37 . 129) (7 . 175) (8 . 176) (9 . 177) (10 . 178) (11 . 179) 
    (38 . 180) (12 . 64) (39 . 65) (188 . 181) (187 . 182) (209 . 183) 
    (210 . 184) (211 . 185) (186 . 186) (89 . 187) (90 . 188) (91 . 189) 
    (92 . 190) (93 . 207) (94 . 192) (106 . 193) (206 . 194) (185 . 195) 
    (95 . 196) (196 . 197) (97 . 198) (98 . 199) (205 . 200) (197 . 201) 
    (184 . 202) (201 . 528)) ((101 . 525) (1 . -29)) ((96 . -238) (105 . -238)
    ) ((105 . -236)) ((101 . 524)) ((1 . -39)) ((1 . -38)) ((1 . -37)) 
    ((93 . 376) (88 . 377) (87 . 378) (1 . -42)) ((93 . 376) (88 . 377) 
    (87 . 378) (1 . -41)) ((92 . 374) (91 . 375) (1 . -45)) ((92 . 374) 
    (91 . 375) (1 . -44)) ((86 . 372) (85 . 373) (1 . -50)) ((86 . 372) 
    (85 . 373) (1 . -49)) ((86 . 372) (85 . 373) (1 . -48)) ((86 . 372) 
    (85 . 373) (1 . -47)) ((84 . 368) (83 . 369) (82 . 370) (81 . 371) 
    (1 . -53)) ((84 . 368) (83 . 369) (82 . 370) (81 . 371) (1 . -52)) 
    ((80 . 366) (79 . 367) (1 . -55)) ((94 . 365) (1 . -57)) ((78 . 364) 
    (1 . -59)) ((77 . 363) (1 . -61)) ((104 . 522) (37 . 129) (7 . 175) 
    (8 . 176) (9 . 177) (10 . 178) (11 . 179) (38 . 180) (12 . 64) (39 . 65) 
    (209 . 183) (210 . 184) (211 . 185) (89 . 187) (90 . 188) (91 . 189) 
    (92 . 190) (93 . 207) (94 . 192) (206 . 194) (95 . 196) (196 . 197) 
    (97 . 198) (98 . 199) (205 . 200) (106 . 193) (197 . 275) (195 . 523)) 
    ((102 . 383) (106 . 427) (93 . 66) (138 . 385) (145 . 428) (198 . 398) 
    (27 . 3) (34 . 4) (35 . 5) (36 . 6) (44 . 7) (45 . 8) (46 . 9) (47 . 10) 
    (48 . 11) (49 . 12) (51 . 13) (50 . 14) (53 . 15) (29 . 16) (30 . 17) 
    (31 . 18) (32 . 19) (33 . 20) (165 . 24) (166 . 25) (167 . 26) (168 . 27) 
    (54 . 28) (169 . 29) (170 . 30) (55 . 31) (56 . 32) (57 . 33) (58 . 34) 
    (59 . 56) (60 . 35) (175 . 38) (176 . 39) (177 . 40) (178 . 41) (199 . 162
    ) (139 . 163) (140 . 164) (142 . 399) (105 . 400)) ((102 . 383) (106 . 427
    ) (138 . 395) (105 . -247) (96 . -247)) ((105 . -244) (96 . -244)) 
    ((103 . 521) (195 . 168) (194 . 169) (193 . 170) (192 . 171) (191 . 172) 
    (190 . 173) (189 . 174) (37 . 129) (7 . 175) (8 . 176) (9 . 177) (10 . 178
    ) (11 . 179) (38 . 180) (188 . 181) (187 . 182) (209 . 183) (210 . 184) 
    (186 . 186) (89 . 187) (90 . 188) (91 . 189) (92 . 190) (93 . 207) 
    (94 . 192) (106 . 193) (206 . 194) (185 . 195) (95 . 196) (196 . 197) 
    (97 . 198) (98 . 199) (205 . 200) (27 . 3) (34 . 4) (35 . 5) (36 . 6) 
    (44 . 7) (45 . 8) (46 . 9) (47 . 10) (48 . 11) (49 . 12) (51 . 13) 
    (50 . 14) (53 . 15) (197 . 201) (184 . 202) (12 . 64) (39 . 65) (13 . 136)
    (29 . 16) (30 . 17) (31 . 18) (32 . 19) (33 . 20) (165 . 24) (166 . 25) 
    (167 . 26) (168 . 27) (54 . 28) (169 . 29) (170 . 30) (55 . 31) (56 . 32) 
    (57 . 33) (58 . 34) (59 . 56) (60 . 35) (201 . 213) (4 . 43) (172 . 214) 
    (14 . 215) (15 . 216) (16 . 217) (17 . 218) (18 . 219) (19 . 220) (20 . 
    221) (21 . 222) (24 . 223) (61 . 224) (208 . 225) (104 . 131) (25 . 226) 
    (26 . 227) (211 . 228) (175 . 38) (176 . 39) (177 . 40) (178 . 41) 
    (127 . 229) (128 . 230) (129 . 231) (130 . 232) (131 . 233) (132 . 234) 
    (133 . 235) (134 . 236) (199 . 57) (126 . 237) (124 . 238) (125 . 297)) 
    ((1 . -4)) ((76 . 362) (1 . -63)) ((73 . 520) (96 . 302)) ((105 . 519)) 
    ((105 . 518)) ((1 . -11)) ((1 . -10)) ((1 . -9)) ((102 . 383) (106 . 427) 
    (93 . 66) (138 . 385) (145 . 428) (198 . 517) (105 . -21) (96 . -21)) 
    ((105 . -18) (96 . -18)) ((105 . -16) (96 . -16)) ((105 . 515) (96 . 516))
    ((101 . 514) (96 . 302)) ((1 . -67)) ((1 . -224)) ((101 . 513)) ((1 . -218
    )) ((1 . -319)) ((37 . 129) (102 . 510) (209 . 511) (118 . 512) (1 . -323)
    ) ((96 . 506) (73 . 507) (120 . 508) (105 . 509)) ((195 . 168) (194 . 169)
    (193 . 170) (192 . 171) (191 . 172) (190 . 173) (189 . 174) (37 . 129) 
    (7 . 175) (8 . 176) (9 . 177) (10 . 178) (11 . 179) (38 . 180) (12 . 64) 
    (39 . 65) (188 . 181) (187 . 182) (209 . 183) (210 . 184) (211 . 185) 
    (186 . 186) (89 . 187) (90 . 188) (91 . 189) (92 . 190) (93 . 207) 
    (94 . 192) (106 . 193) (206 . 194) (185 . 195) (95 . 196) (196 . 197) 
    (97 . 198) (98 . 199) (205 . 200) (197 . 201) (184 . 202) (104 . 208) 
    (201 . 209) (171 . 503) (100 . 314) (102 . 315) (135 . 316) (136 . 317) 
    (137 . 504) (103 . 505)) ((1 . -272)) ((96 . -274) (103 . -274)) ((1 . 
    -278)) ((1 . -280)) ((101 . 502)) ((1 . -282)) ((1 . -316)) ((1 . -313)) 
    ((1 . -310)) ((1 . -309)) ((61 . 501) (96 . 302)) ((195 . 168) (194 . 169)
    (193 . 170) (192 . 171) (191 . 172) (190 . 173) (189 . 174) (37 . 129) 
    (7 . 175) (8 . 176) (9 . 177) (10 . 178) (11 . 179) (38 . 180) (12 . 64) 
    (39 . 65) (188 . 181) (187 . 182) (209 . 183) (210 . 184) (211 . 185) 
    (186 . 186) (89 . 187) (90 . 188) (91 . 189) (92 . 190) (93 . 207) 
    (94 . 192) (106 . 193) (206 . 194) (185 . 195) (95 . 196) (196 . 197) 
    (97 . 198) (98 . 199) (205 . 200) (197 . 201) (184 . 202) (201 . 213) 
    (208 . 499) (122 . 500) (61 . -311)) ((106 . 498)) ((105 . 497) (96 . 302)
    ) ((105 . 496) (96 . 302)) ((96 . 302) (105 . 495)) ((1 . -80)) ((1 . -293
    )) ((195 . 168) (194 . 169) (193 . 170) (192 . 171) (191 . 172) (190 . 173
    ) (189 . 174) (37 . 129) (7 . 175) (8 . 176) (9 . 177) (10 . 178) (11 . 
    179) (38 . 180) (188 . 181) (187 . 182) (209 . 183) (210 . 184) (186 . 186
    ) (89 . 187) (90 . 188) (91 . 189) (92 . 190) (93 . 207) (94 . 192) 
    (106 . 193) (206 . 194) (185 . 195) (95 . 196) (196 . 197) (97 . 198) 
    (98 . 199) (205 . 200) (197 . 201) (184 . 202) (12 . 64) (39 . 65) 
    (13 . 136) (201 . 213) (4 . 43) (172 . 214) (14 . 215) (15 . 216) (16 . 
    217) (17 . 218) (18 . 219) (19 . 220) (20 . 221) (21 . 222) (24 . 223) 
    (61 . 224) (208 . 225) (104 . 131) (25 . 226) (26 . 227) (211 . 228) 
    (127 . 229) (128 . 230) (129 . 231) (130 . 232) (131 . 233) (132 . 234) 
    (133 . 235) (134 . 236) (126 . 494)) ((1 . -291)) ((1 . -163)) ((1 . -162)
    ) ((106 . 493) (105 . -167) (96 . -167)) ((105 . -166) (96 . -166)) 
    ((105 . -165) (96 . -165)) ((105 . -164) (96 . -164)) ((105 . -160) 
    (96 . -160)) ((105 . 491) (96 . 492)) ((105 . -157) (96 . -157)) ((1 . 
    -147)) ((1 . -171)) ((1 . -177)) ((1 . -198)) ((1 . -196)) ((6 . 145) 
    (109 . 146) (179 . 490) (5 . -353) (1 . -353)) ((1 . -174)) ((1 . -179)) 
    ((1 . -201)) ((5 . -189) (1 . -189)) ((105 . -159) (96 . -159)) ((27 . 3) 
    (34 . 4) (35 . 5) (36 . 6) (44 . 7) (45 . 8) (46 . 9) (47 . 10) (48 . 11) 
    (49 . 12) (51 . 13) (50 . 14) (53 . 15) (29 . 16) (30 . 17) (31 . 18) 
    (32 . 19) (33 . 20) (165 . 24) (166 . 25) (167 . 26) (168 . 27) (54 . 28) 
    (169 . 29) (170 . 30) (55 . 31) (56 . 32) (57 . 33) (58 . 34) (59 . 56) 
    (60 . 35) (40 . 21) (41 . 22) (42 . 23) (175 . 38) (176 . 356) (177 . 357)
    (178 . 41) (199 . 358) (151 . 359) (161 . 472) (39 . 473) (156 . 474) 
    (37 . 475) (38 . 476) (203 . 477) (157 . 574)) ((27 . 3) (34 . 4) (35 . 5)
    (36 . 6) (44 . 7) (45 . 8) (46 . 9) (47 . 10) (48 . 11) (49 . 12) (51 . 13
    ) (50 . 14) (53 . 15) (29 . 16) (30 . 17) (31 . 18) (32 . 19) (33 . 20) 
    (165 . 24) (166 . 25) (167 . 26) (168 . 27) (54 . 28) (169 . 29) (170 . 30
    ) (55 . 31) (56 . 32) (57 . 33) (58 . 34) (59 . 56) (60 . 35) (40 . 21) 
    (41 . 22) (42 . 23) (175 . 38) (176 . 356) (177 . 357) (178 . 41) (199 . 
    358) (151 . 359) (161 . 472) (39 . 473) (156 . 474) (37 . 475) (38 . 476) 
    (203 . 477) (157 . 478) (158 . 573)) ((1 . -292)) ((195 . 168) (194 . 169)
    (193 . 170) (192 . 171) (191 . 172) (190 . 173) (189 . 174) (37 . 129) 
    (7 . 175) (8 . 176) (9 . 177) (10 . 178) (11 . 179) (38 . 180) (188 . 181)
    (187 . 182) (209 . 183) (210 . 184) (186 . 186) (89 . 187) (90 . 188) 
    (91 . 189) (92 . 190) (93 . 207) (94 . 192) (106 . 193) (206 . 194) 
    (185 . 195) (95 . 196) (196 . 197) (97 . 198) (98 . 199) (205 . 200) 
    (197 . 201) (184 . 202) (12 . 64) (39 . 65) (13 . 136) (201 . 213) 
    (4 . 43) (172 . 214) (14 . 215) (15 . 216) (16 . 217) (17 . 218) (18 . 219
    ) (19 . 220) (20 . 221) (21 . 222) (24 . 223) (61 . 224) (208 . 225) 
    (104 . 131) (25 . 226) (26 . 227) (211 . 228) (127 . 229) (128 . 230) 
    (129 . 231) (130 . 232) (131 . 233) (132 . 234) (133 . 235) (134 . 236) 
    (126 . 572)) ((195 . 168) (194 . 169) (193 . 170) (192 . 171) (191 . 172) 
    (190 . 173) (189 . 174) (37 . 129) (7 . 175) (8 . 176) (9 . 177) (10 . 178
    ) (11 . 179) (38 . 180) (188 . 181) (187 . 182) (209 . 183) (210 . 184) 
    (186 . 186) (89 . 187) (90 . 188) (91 . 189) (92 . 190) (93 . 207) 
    (94 . 192) (106 . 193) (206 . 194) (185 . 195) (95 . 196) (196 . 197) 
    (97 . 198) (98 . 199) (205 . 200) (197 . 201) (184 . 202) (12 . 64) 
    (39 . 65) (13 . 136) (201 . 213) (4 . 43) (172 . 214) (14 . 215) (15 . 216
    ) (16 . 217) (17 . 218) (18 . 219) (19 . 220) (20 . 221) (21 . 222) 
    (24 . 223) (61 . 224) (208 . 225) (104 . 131) (25 . 226) (26 . 227) 
    (211 . 228) (127 . 229) (128 . 230) (129 . 231) (130 . 232) (131 . 233) 
    (132 . 234) (133 . 235) (134 . 236) (126 . 571)) ((195 . 168) (194 . 169) 
    (193 . 170) (192 . 171) (191 . 172) (190 . 173) (189 . 174) (37 . 129) 
    (7 . 175) (8 . 176) (9 . 177) (10 . 178) (11 . 179) (38 . 180) (188 . 181)
    (187 . 182) (209 . 183) (210 . 184) (186 . 186) (89 . 187) (90 . 188) 
    (91 . 189) (92 . 190) (93 . 207) (94 . 192) (106 . 193) (206 . 194) 
    (185 . 195) (95 . 196) (196 . 197) (97 . 198) (98 . 199) (205 . 200) 
    (197 . 201) (184 . 202) (12 . 64) (39 . 65) (13 . 136) (201 . 213) 
    (4 . 43) (172 . 214) (14 . 215) (15 . 216) (16 . 217) (17 . 218) (18 . 219
    ) (19 . 220) (20 . 221) (21 . 222) (24 . 223) (61 . 224) (208 . 225) 
    (104 . 131) (25 . 226) (26 . 227) (211 . 228) (127 . 229) (128 . 230) 
    (129 . 231) (130 . 232) (131 . 233) (132 . 234) (133 . 235) (134 . 236) 
    (126 . 570)) ((195 . 168) (194 . 169) (193 . 170) (192 . 171) (191 . 172) 
    (190 . 173) (189 . 174) (37 . 129) (7 . 175) (8 . 176) (9 . 177) (10 . 178
    ) (11 . 179) (38 . 180) (12 . 64) (39 . 65) (188 . 181) (187 . 182) 
    (209 . 183) (210 . 184) (211 . 185) (186 . 186) (89 . 187) (90 . 188) 
    (91 . 189) (92 . 190) (93 . 207) (94 . 192) (106 . 193) (206 . 194) 
    (185 . 195) (95 . 196) (196 . 197) (97 . 198) (98 . 199) (205 . 200) 
    (197 . 201) (184 . 202) (201 . 213) (208 . 569)) ((96 . 302) (61 . -312) 
    (105 . -312)) ((61 . 568)) ((1 . -308)) ((1 . -281)) ((96 . -277) (103 . 
    -277)) ((195 . 168) (194 . 169) (193 . 170) (192 . 171) (191 . 172) 
    (190 . 173) (189 . 174) (37 . 129) (7 . 175) (8 . 176) (9 . 177) (10 . 178
    ) (11 . 179) (38 . 180) (12 . 64) (39 . 65) (188 . 181) (187 . 182) 
    (209 . 183) (210 . 184) (211 . 185) (186 . 186) (89 . 187) (90 . 188) 
    (91 . 189) (92 . 190) (93 . 207) (94 . 192) (106 . 193) (206 . 194) 
    (185 . 195) (95 . 196) (196 . 197) (97 . 198) (98 . 199) (205 . 200) 
    (197 . 201) (184 . 202) (104 . 208) (201 . 209) (171 . 567)) ((1 . -273)) 
    ((37 . 129) (102 . 510) (209 . 511) (118 . 566)) ((37 . 129) (102 . 563) 
    (209 . 564) (117 . 565) (1 . -328)) ((105 . 559) (96 . 560) (73 . 561) 
    (119 . 562)) ((1 . -320)) ((12 . 64) (39 . 65) (211 . 558)) ((106 . 557) 
    (37 . 243)) ((1 . -324)) ((1 . -223)) ((1 . -7)) ((1 . -8)) ((27 . 3) 
    (34 . 4) (35 . 5) (36 . 6) (44 . 7) (45 . 8) (46 . 9) (47 . 10) (48 . 11) 
    (49 . 12) (51 . 13) (50 . 14) (53 . 15) (29 . 16) (30 . 17) (31 . 18) 
    (32 . 19) (33 . 20) (165 . 24) (166 . 25) (167 . 26) (168 . 27) (54 . 28) 
    (169 . 29) (170 . 30) (55 . 31) (56 . 32) (57 . 33) (58 . 34) (59 . 56) 
    (60 . 35) (175 . 38) (176 . 39) (177 . 40) (178 . 41) (199 . 439) (200 . 
    555) (195 . 168) (194 . 169) (193 . 170) (192 . 171) (191 . 172) (190 . 
    173) (189 . 174) (37 . 129) (7 . 175) (8 . 176) (9 . 177) (10 . 178) 
    (11 . 179) (38 . 180) (12 . 64) (39 . 65) (188 . 181) (187 . 182) (209 . 
    183) (210 . 184) (211 . 185) (186 . 186) (89 . 187) (90 . 188) (91 . 189) 
    (92 . 190) (93 . 207) (94 . 192) (106 . 193) (206 . 194) (185 . 195) 
    (95 . 196) (196 . 197) (97 . 198) (98 . 199) (205 . 200) (197 . 201) 
    (184 . 202) (201 . 556)) ((105 . -20) (96 . -20)) ((104 . 522)) ((104 . 
    522) (1 . -27)) ((37 . 129) (7 . 175) (8 . 176) (9 . 177) (10 . 178) 
    (11 . 179) (38 . 180) (12 . 64) (39 . 65) (209 . 183) (210 . 184) (211 . 
    185) (89 . 187) (90 . 188) (91 . 189) (92 . 190) (93 . 207) (94 . 192) 
    (206 . 194) (95 . 196) (196 . 197) (97 . 198) (98 . 199) (205 . 200) 
    (106 . 193) (197 . 275) (195 . 168) (194 . 169) (193 . 170) (192 . 171) 
    (191 . 172) (190 . 173) (189 . 174) (188 . 181) (187 . 182) (186 . 186) 
    (185 . 195) (184 . 554)) ((105 . 553)) ((195 . 168) (194 . 169) (193 . 170
    ) (192 . 171) (191 . 172) (190 . 173) (189 . 174) (37 . 129) (7 . 175) 
    (8 . 176) (9 . 177) (10 . 178) (11 . 179) (38 . 180) (12 . 64) (39 . 65) 
    (188 . 181) (187 . 182) (209 . 183) (210 . 184) (211 . 185) (186 . 186) 
    (89 . 187) (90 . 188) (91 . 189) (92 . 190) (93 . 207) (94 . 192) (106 . 
    193) (206 . 194) (100 . 314) (102 . 315) (185 . 195) (95 . 196) (196 . 197
    ) (97 . 198) (98 . 199) (205 . 200) (135 . 316) (197 . 201) (184 . 202) 
    (136 . 317) (104 . 208) (201 . 209) (171 . 318) (137 . 319) (202 . 552)) 
    ((1 . -35)) ((1 . -222)) ((1 . -265)) ((195 . 168) (194 . 169) (193 . 170)
    (192 . 171) (191 . 172) (190 . 173) (189 . 174) (37 . 129) (7 . 175) 
    (8 . 176) (9 . 177) (10 . 178) (11 . 179) (38 . 180) (12 . 64) (39 . 65) 
    (188 . 181) (187 . 182) (209 . 183) (210 . 184) (211 . 185) (186 . 186) 
    (89 . 187) (90 . 188) (91 . 189) (92 . 190) (93 . 207) (94 . 192) (106 . 
    193) (206 . 194) (185 . 195) (95 . 196) (196 . 197) (97 . 198) (98 . 199) 
    (205 . 200) (197 . 201) (184 . 202) (201 . 551)) ((1 . -258)) ((101 . 550)
    ) ((195 . 168) (194 . 169) (193 . 170) (192 . 171) (191 . 172) (190 . 173)
    (189 . 174) (37 . 129) (7 . 175) (8 . 176) (9 . 177) (10 . 178) (11 . 179)
    (38 . 180) (12 . 64) (39 . 65) (188 . 181) (187 . 182) (209 . 183) 
    (210 . 184) (211 . 185) (186 . 186) (89 . 187) (90 . 188) (91 . 189) 
    (92 . 190) (93 . 207) (94 . 192) (106 . 193) (206 . 194) (185 . 195) 
    (95 . 196) (196 . 197) (97 . 198) (98 . 199) (205 . 200) (197 . 201) 
    (184 . 202) (201 . 548) (31 . 18) (32 . 19) (33 . 20) (176 . 156) (101 . 
    549)) ((1 . -259)) ((1 . -268)) ((1 . -249)) ((1 . -267)) ((105 . 547)) 
    ((31 . 18) (32 . 19) (33 . 20) (176 . 142) (143 . 546)) ((1 . -253)) 
    ((101 . 545) (1 . -29)) ((101 . 544)) ((195 . 168) (194 . 169) (193 . 170)
    (192 . 171) (191 . 172) (190 . 173) (189 . 174) (37 . 129) (7 . 175) 
    (8 . 176) (9 . 177) (10 . 178) (11 . 179) (38 . 180) (12 . 64) (39 . 65) 
    (188 . 181) (187 . 182) (209 . 183) (210 . 184) (211 . 185) (186 . 186) 
    (89 . 187) (90 . 188) (91 . 189) (92 . 190) (93 . 207) (94 . 192) (106 . 
    193) (206 . 194) (185 . 195) (95 . 196) (196 . 197) (97 . 198) (98 . 199) 
    (205 . 200) (197 . 201) (184 . 202) (201 . 541) (31 . 18) (32 . 19) 
    (33 . 20) (176 . 156) (101 . 542) (57 . 543)) ((5 . -345) (1 . -345)) 
    ((101 . 594)) ((1 . -251)) ((195 . 168) (194 . 169) (193 . 170) (192 . 171
    ) (191 . 172) (190 . 173) (189 . 174) (37 . 129) (7 . 175) (8 . 176) 
    (9 . 177) (10 . 178) (11 . 179) (38 . 180) (12 . 64) (39 . 65) (188 . 181)
    (187 . 182) (209 . 183) (210 . 184) (211 . 185) (186 . 186) (89 . 187) 
    (90 . 188) (91 . 189) (92 . 190) (93 . 207) (94 . 192) (106 . 193) 
    (206 . 194) (185 . 195) (95 . 196) (196 . 197) (97 . 198) (98 . 199) 
    (205 . 200) (197 . 201) (184 . 202) (201 . 593)) ((1 . -252)) ((1 . -264))
    ((101 . 591) (31 . 18) (32 . 19) (33 . 20) (176 . 156) (195 . 168) 
    (194 . 169) (193 . 170) (192 . 171) (191 . 172) (190 . 173) (189 . 174) 
    (37 . 129) (7 . 175) (8 . 176) (9 . 177) (10 . 178) (11 . 179) (38 . 180) 
    (12 . 64) (39 . 65) (188 . 181) (187 . 182) (209 . 183) (210 . 184) 
    (211 . 185) (186 . 186) (89 . 187) (90 . 188) (91 . 189) (92 . 190) 
    (93 . 207) (94 . 192) (106 . 193) (206 . 194) (185 . 195) (95 . 196) 
    (196 . 197) (97 . 198) (98 . 199) (205 . 200) (197 . 201) (184 . 202) 
    (201 . 592)) ((1 . -266)) ((101 . 590)) ((1 . -262)) ((1 . -257)) (
    (101 . 589)) ((103 . 587) (96 . 588)) ((1 . -5)) ((1 . -65)) ((105 . -19) 
    (96 . -19)) ((105 . -17) (96 . -17)) ((12 . 64) (39 . 65) (211 . 586)) 
    ((101 . 585)) ((1 . -321)) ((37 . 129) (102 . 563) (209 . 564) (117 . 584)
    ) ((37 . 129) (209 . 583) (105 . -333) (96 . -333)) ((105 . 581) (96 . 582
    )) ((12 . 64) (39 . 65) (211 . 580)) ((106 . 579) (37 . 243)) ((1 . -329))
    ((1 . -325)) ((96 . -276) (103 . -276)) ((195 . 168) (194 . 169) (193 . 
    170) (192 . 171) (191 . 172) (190 . 173) (189 . 174) (37 . 129) (7 . 175) 
    (8 . 176) (9 . 177) (10 . 178) (11 . 179) (38 . 180) (12 . 64) (39 . 65) 
    (188 . 181) (187 . 182) (209 . 183) (210 . 184) (211 . 185) (186 . 186) 
    (89 . 187) (90 . 188) (91 . 189) (92 . 190) (93 . 207) (94 . 192) (106 . 
    193) (206 . 194) (185 . 195) (95 . 196) (196 . 197) (97 . 198) (98 . 199) 
    (205 . 200) (197 . 201) (184 . 202) (201 . 213) (208 . 499) (122 . 578) 
    (105 . -311)) ((105 . 577) (96 . 302)) ((1 . -305)) ((1 . -304)) ((22 . 
    576) (1 . -302)) ((105 . 575) (96 . 492)) ((105 . -161) (96 . -161)) 
    ((105 . -168) (96 . -168)) ((195 . 168) (194 . 169) (193 . 170) (192 . 171
    ) (191 . 172) (190 . 173) (189 . 174) (37 . 129) (7 . 175) (8 . 176) 
    (9 . 177) (10 . 178) (11 . 179) (38 . 180) (188 . 181) (187 . 182) 
    (209 . 183) (210 . 184) (186 . 186) (89 . 187) (90 . 188) (91 . 189) 
    (92 . 190) (93 . 207) (94 . 192) (106 . 193) (206 . 194) (185 . 195) 
    (95 . 196) (196 . 197) (97 . 198) (98 . 199) (205 . 200) (197 . 201) 
    (184 . 202) (12 . 64) (39 . 65) (13 . 136) (201 . 213) (4 . 43) (172 . 214
    ) (14 . 215) (15 . 216) (16 . 217) (17 . 218) (18 . 219) (19 . 220) 
    (20 . 221) (21 . 222) (24 . 223) (61 . 224) (208 . 225) (104 . 131) 
    (25 . 226) (26 . 227) (211 . 228) (127 . 229) (128 . 230) (129 . 231) 
    (130 . 232) (131 . 233) (132 . 234) (133 . 235) (134 . 236) (126 . 605)) 
    ((61 . 604)) ((105 . 603)) ((195 . 168) (194 . 169) (193 . 170) (192 . 171
    ) (191 . 172) (190 . 173) (189 . 174) (37 . 129) (7 . 175) (8 . 176) 
    (9 . 177) (10 . 178) (11 . 179) (38 . 180) (12 . 64) (39 . 65) (188 . 181)
    (187 . 182) (209 . 183) (210 . 184) (211 . 185) (186 . 186) (89 . 187) 
    (90 . 188) (91 . 189) (92 . 190) (93 . 207) (94 . 192) (106 . 193) 
    (206 . 194) (185 . 195) (95 . 196) (196 . 197) (97 . 198) (98 . 199) 
    (205 . 200) (197 . 201) (184 . 202) (201 . 213) (208 . 602)) ((101 . 601))
    ((1 . -322)) ((37 . 129) (209 . 600)) ((37 . 243) (105 . -334) (96 . -334)
    ) ((1 . -330)) ((37 . 129) (209 . 599)) ((105 . 598)) ((1 . -14)) (
    (103 . 597) (195 . 168) (194 . 169) (193 . 170) (192 . 171) (191 . 172) 
    (190 . 173) (189 . 174) (37 . 129) (7 . 175) (8 . 176) (9 . 177) (10 . 178
    ) (11 . 179) (38 . 180) (12 . 64) (39 . 65) (188 . 181) (187 . 182) 
    (209 . 183) (210 . 184) (211 . 185) (186 . 186) (89 . 187) (90 . 188) 
    (91 . 189) (92 . 190) (93 . 207) (94 . 192) (106 . 193) (206 . 194) 
    (185 . 195) (95 . 196) (196 . 197) (97 . 198) (98 . 199) (205 . 200) 
    (197 . 201) (184 . 202) (104 . 208) (201 . 209) (171 . 503) (100 . 314) 
    (102 . 315) (135 . 316) (136 . 317) (137 . 504)) ((1 . -263)) ((1 . -261))
    ((1 . -255)) ((101 . 596)) ((101 . 595)) ((1 . -250)) ((1 . -256)) 
    ((1 . -254)) ((1 . -15)) ((1 . -326)) ((106 . 609) (37 . 243)) ((37 . 243)
    (105 . -335) (96 . -335)) ((37 . 129) (209 . 608)) ((105 . 607) (96 . 302)
    ) ((195 . 168) (194 . 169) (193 . 170) (192 . 171) (191 . 172) (190 . 173)
    (189 . 174) (37 . 129) (7 . 175) (8 . 176) (9 . 177) (10 . 178) (11 . 179)
    (38 . 180) (188 . 181) (187 . 182) (209 . 183) (210 . 184) (186 . 186) 
    (89 . 187) (90 . 188) (91 . 189) (92 . 190) (93 . 207) (94 . 192) (106 . 
    193) (206 . 194) (185 . 195) (95 . 196) (196 . 197) (97 . 198) (98 . 199) 
    (205 . 200) (197 . 201) (184 . 202) (12 . 64) (39 . 65) (13 . 136) 
    (201 . 213) (4 . 43) (172 . 214) (14 . 215) (15 . 216) (16 . 217) (17 . 
    218) (18 . 219) (19 . 220) (20 . 221) (21 . 222) (24 . 223) (61 . 224) 
    (208 . 225) (104 . 131) (25 . 226) (26 . 227) (211 . 228) (127 . 229) 
    (128 . 230) (129 . 231) (130 . 232) (131 . 233) (132 . 234) (133 . 235) 
    (134 . 236) (126 . 606)) ((1 . -306)) ((1 . -303)) ((1 . -307)) ((1 . -331
    )) ((106 . 611) (37 . 243)) ((12 . 64) (39 . 65) (211 . 610)) ((105 . 613)
    ) ((195 . 168) (194 . 169) (193 . 170) (192 . 171) (191 . 172) (190 . 173)
    (189 . 174) (37 . 129) (7 . 175) (8 . 176) (9 . 177) (10 . 178) (11 . 179)
    (38 . 180) (12 . 64) (39 . 65) (188 . 181) (187 . 182) (209 . 183) 
    (210 . 184) (211 . 185) (186 . 186) (89 . 187) (90 . 188) (91 . 189) 
    (92 . 190) (93 . 207) (94 . 192) (106 . 193) (206 . 194) (185 . 195) 
    (95 . 196) (196 . 197) (97 . 198) (98 . 199) (205 . 200) (197 . 201) 
    (184 . 202) (201 . 213) (208 . 612)) ((105 . 614) (96 . 302)) ((1 . -327))
    ((1 . -332))))

(define c99-rto-v
  #(#f 206 206 206 206 206 205 205 205 205 205 205 205 205 205 205 204 204 
    204 204 200 200 197 197 197 197 197 197 196 196 196 196 196 196 195 195 
    194 194 194 194 193 193 193 192 192 192 191 191 191 191 191 190 190 190 
    189 189 188 188 187 187 186 186 185 185 184 184 201 201 183 183 183 183 
    183 183 183 183 183 183 183 208 208 148 124 124 180 199 199 199 199 199 
    199 199 199 182 182 174 174 174 174 178 178 178 178 178 177 177 177 177 
    177 177 177 177 170 170 170 170 170 170 170 170 170 170 170 170 170 170 
    170 170 170 170 170 170 170 170 170 170 170 170 169 169 169 168 168 168 
    168 163 163 164 164 161 161 161 159 159 162 162 162 162 160 160 158 158 
    156 156 157 157 157 157 157 181 181 167 167 167 167 167 167 167 167 167 
    167 155 155 154 154 154 154 154 154 153 153 151 151 151 151 150 150 149 
    149 149 166 166 166 166 166 147 147 146 146 176 176 176 175 175 173 173 
    144 144 144 144 144 144 144 144 144 144 144 144 144 145 145 145 145 143 
    143 142 142 140 140 139 139 139 141 141 203 203 198 198 198 138 138 138 
    138 138 138 138 138 138 138 138 138 138 138 138 138 138 138 138 138 138 
    165 171 171 171 202 202 202 202 137 136 136 135 135 126 126 126 126 126 
    126 126 126 134 134 134 133 133 207 207 125 125 132 132 131 131 131 130 
    130 130 123 123 123 122 122 129 129 129 129 129 128 172 172 172 172 121 
    121 121 118 118 120 120 120 117 117 119 119 119 212 116 116 115 115 115 
    115 115 115 115 115 112 111 114 114 110 110 179 179 211 211 210 210 210 
    210 210 210 209 209 109 152 127 113))

(define c99-mtab
  '(($start . 212) ("_Pragma" . 3) (cpp-stmt . 4) ($lone-comm . 5) ($code-comm
    . 6) ($chlit/U . 7) ($chlit/u . 8) ($chlit/L . 9) ($chlit . 10) ($float . 
    11) (cpp-ident . 12) ("asm" . 13) ("return" . 14) ("break" . 15) (
    "continue" . 16) ("goto" . 17) ("for" . 18) ("do" . 19) ("while" . 20) 
    ("switch" . 21) ("else" . 22) (then . 23) ("if" . 24) ("default" . 25) 
    ("case" . 26) (typename . 27) ("..." . 28) ("_Noreturn" . 29) ("inline" . 
    30) ("restrict" . 31) ("volatile" . 32) ("const" . 33) ("enum" . 34) 
    ("union" . 35) ("struct" . 36) ($string . 37) ($fixed . 38) ($ident . 39) 
    ("__alignof__" . 40) ("__aligned__" . 41) ("__packed__" . 42) (
    "__attribute__" . 43) ("_Complex" . 44) ("double" . 45) ("float" . 46) 
    ("char" . 47) ("unsigned" . 48) ("long" . 49) ("signed" . 50) ("int" . 51)
    (imp . 52) ("short" . 53) ("_Bool" . 54) ("void" . 55) ("typedef" . 56) 
    ("static" . 57) ("register" . 58) ("extern" . 59) ("auto" . 60) (";" . 61)
    ("|=" . 62) ("^=" . 63) ("&=" . 64) (">>=" . 65) ("<<=" . 66) ("%=" . 67) 
    ("/=" . 68) ("*=" . 69) ("-=" . 70) ("+=" . 71) ("=" . 72) (":" . 73) 
    ("?" . 74) ("||" . 75) ("&&" . 76) ("|" . 77) ("^" . 78) ("!=" . 79) 
    ("==" . 80) (">=" . 81) ("<=" . 82) (">" . 83) ("<" . 84) (">>" . 85) 
    ("<<" . 86) ("%" . 87) ("/" . 88) ("!" . 89) ("~" . 90) ("-" . 91) 
    ("+" . 92) ("*" . 93) ("&" . 94) ("sizeof" . 95) ("," . 96) ("--" . 97) 
    ("++" . 98) ("->" . 99) ("." . 100) ("]" . 101) ("[" . 102) ("}" . 103) 
    ("{" . 104) (")" . 105) ("(" . 106) ($error . 2) ($end . 108)))

(define c99-tables
  (list
   (cons 'len-v c99-len-v)
   (cons 'pat-v c99-pat-v)
   (cons 'rto-v c99-rto-v)
   (cons 'mtab c99-mtab)))

;;; end tables
